/* DO NOT EDIT! GENERATED AUTOMATICALLY! */
#ifndef LIBTEXTSTYLE_CONFIG_H
#define LIBTEXTSTYLE_CONFIG_H

#include "../config.h"

#endif /* LIBTEXTSTYLE_CONFIG_H */
#define isatty libtextstyle_isatty
#define __oldXMLWDcompatibility libtextstyle___oldXMLWDcompatibility
#define __xmlBufferAllocScheme libtextstyle___xmlBufferAllocScheme
#define __xmlDefaultBufferSize libtextstyle___xmlDefaultBufferSize
#define __xmlDefaultSAXLocator libtextstyle___xmlDefaultSAXLocator
#define __xmlDeregisterNodeDefaultValue libtextstyle___xmlDeregisterNodeDefaultValue
#define __xmlDoValidityCheckingDefaultValue libtextstyle___xmlDoValidityCheckingDefaultValue
#define __xmlErrEncoding libtextstyle___xmlErrEncoding
#define __xmlGenericError libtextstyle___xmlGenericError
#define __xmlGenericErrorContext libtextstyle___xmlGenericErrorContext
#define __xmlGetWarningsDefaultValue libtextstyle___xmlGetWarningsDefaultValue
#define __xmlGlobalInitMutexDestroy libtextstyle___xmlGlobalInitMutexDestroy
#define __xmlGlobalInitMutexLock libtextstyle___xmlGlobalInitMutexLock
#define __xmlGlobalInitMutexUnlock libtextstyle___xmlGlobalInitMutexUnlock
#define __xmlIOErr libtextstyle___xmlIOErr
#define __xmlIndentTreeOutput libtextstyle___xmlIndentTreeOutput
#define __xmlInitializeDict libtextstyle___xmlInitializeDict
#define __xmlKeepBlanksDefaultValue libtextstyle___xmlKeepBlanksDefaultValue
#define __xmlLastError libtextstyle___xmlLastError
#define __xmlLineNumbersDefaultValue libtextstyle___xmlLineNumbersDefaultValue
#define __xmlLoadExtDtdDefaultValue libtextstyle___xmlLoadExtDtdDefaultValue
#define __xmlLoaderErr libtextstyle___xmlLoaderErr
#define __xmlOutputBufferCreateFilenameValue libtextstyle___xmlOutputBufferCreateFilenameValue
#define __xmlParserDebugEntities libtextstyle___xmlParserDebugEntities
#define __xmlParserInputBufferCreateFilename libtextstyle___xmlParserInputBufferCreateFilename
#define __xmlParserInputBufferCreateFilenameValue libtextstyle___xmlParserInputBufferCreateFilenameValue
#define __xmlParserVersion libtextstyle___xmlParserVersion
#define __xmlPedanticParserDefaultValue libtextstyle___xmlPedanticParserDefaultValue
#define __xmlRaiseError libtextstyle___xmlRaiseError
#define __xmlRegisterCallbacks libtextstyle___xmlRegisterCallbacks
#define __xmlRegisterNodeDefaultValue libtextstyle___xmlRegisterNodeDefaultValue
#define __xmlSaveNoEmptyTags libtextstyle___xmlSaveNoEmptyTags
#define __xmlSimpleError libtextstyle___xmlSimpleError
#define __xmlStructuredError libtextstyle___xmlStructuredError
#define __xmlStructuredErrorContext libtextstyle___xmlStructuredErrorContext
#define __xmlSubstituteEntitiesDefaultValue libtextstyle___xmlSubstituteEntitiesDefaultValue
#define __xmlTreeIndentString libtextstyle___xmlTreeIndentString
#define activate_term_non_default_mode libtextstyle_activate_term_non_default_mode
#define activate_term_style_controller libtextstyle_activate_term_style_controller
#define at_fatal_signal libtextstyle_at_fatal_signal
#define base_len libtextstyle_base_len
#define block_fatal_signals libtextstyle_block_fatal_signals
#define c_strcasecmp libtextstyle_c_strcasecmp
#define c_strncasecmp libtextstyle_c_strncasecmp
#define concatenated_filename libtextstyle_concatenated_filename
#define cr_additional_sel_append libtextstyle_cr_additional_sel_append
#define cr_additional_sel_destroy libtextstyle_cr_additional_sel_destroy
#define cr_additional_sel_dump libtextstyle_cr_additional_sel_dump
#define cr_additional_sel_new libtextstyle_cr_additional_sel_new
#define cr_additional_sel_new_with_type libtextstyle_cr_additional_sel_new_with_type
#define cr_additional_sel_one_to_string libtextstyle_cr_additional_sel_one_to_string
#define cr_additional_sel_prepend libtextstyle_cr_additional_sel_prepend
#define cr_additional_sel_set_attr_sel libtextstyle_cr_additional_sel_set_attr_sel
#define cr_additional_sel_set_class_name libtextstyle_cr_additional_sel_set_class_name
#define cr_additional_sel_set_id_name libtextstyle_cr_additional_sel_set_id_name
#define cr_additional_sel_set_pseudo libtextstyle_cr_additional_sel_set_pseudo
#define cr_additional_sel_to_string libtextstyle_cr_additional_sel_to_string
#define cr_attr_sel_append_attr_sel libtextstyle_cr_attr_sel_append_attr_sel
#define cr_attr_sel_destroy libtextstyle_cr_attr_sel_destroy
#define cr_attr_sel_dump libtextstyle_cr_attr_sel_dump
#define cr_attr_sel_new libtextstyle_cr_attr_sel_new
#define cr_attr_sel_prepend_attr_sel libtextstyle_cr_attr_sel_prepend_attr_sel
#define cr_attr_sel_to_string libtextstyle_cr_attr_sel_to_string
#define cr_cascade_destroy libtextstyle_cr_cascade_destroy
#define cr_cascade_get_sheet libtextstyle_cr_cascade_get_sheet
#define cr_cascade_new libtextstyle_cr_cascade_new
#define cr_cascade_ref libtextstyle_cr_cascade_ref
#define cr_cascade_set_sheet libtextstyle_cr_cascade_set_sheet
#define cr_cascade_unref libtextstyle_cr_cascade_unref
#define cr_declaration_append libtextstyle_cr_declaration_append
#define cr_declaration_append2 libtextstyle_cr_declaration_append2
#define cr_declaration_destroy libtextstyle_cr_declaration_destroy
#define cr_declaration_dump libtextstyle_cr_declaration_dump
#define cr_declaration_dump_one libtextstyle_cr_declaration_dump_one
#define cr_declaration_get_by_prop_name libtextstyle_cr_declaration_get_by_prop_name
#define cr_declaration_get_from_list libtextstyle_cr_declaration_get_from_list
#define cr_declaration_list_to_string libtextstyle_cr_declaration_list_to_string
#define cr_declaration_list_to_string2 libtextstyle_cr_declaration_list_to_string2
#define cr_declaration_new libtextstyle_cr_declaration_new
#define cr_declaration_nr_props libtextstyle_cr_declaration_nr_props
#define cr_declaration_parse_from_buf libtextstyle_cr_declaration_parse_from_buf
#define cr_declaration_parse_list_from_buf libtextstyle_cr_declaration_parse_list_from_buf
#define cr_declaration_prepend libtextstyle_cr_declaration_prepend
#define cr_declaration_ref libtextstyle_cr_declaration_ref
#define cr_declaration_to_string libtextstyle_cr_declaration_to_string
#define cr_declaration_unlink libtextstyle_cr_declaration_unlink
#define cr_declaration_unref libtextstyle_cr_declaration_unref
#define cr_doc_handler_associate_a_parser libtextstyle_cr_doc_handler_associate_a_parser
#define cr_doc_handler_destroy libtextstyle_cr_doc_handler_destroy
#define cr_doc_handler_get_ctxt libtextstyle_cr_doc_handler_get_ctxt
#define cr_doc_handler_get_result libtextstyle_cr_doc_handler_get_result
#define cr_doc_handler_new libtextstyle_cr_doc_handler_new
#define cr_doc_handler_ref libtextstyle_cr_doc_handler_ref
#define cr_doc_handler_set_ctxt libtextstyle_cr_doc_handler_set_ctxt
#define cr_doc_handler_set_default_sac_handler libtextstyle_cr_doc_handler_set_default_sac_handler
#define cr_doc_handler_set_result libtextstyle_cr_doc_handler_set_result
#define cr_doc_handler_unref libtextstyle_cr_doc_handler_unref
#define cr_enc_handler_convert_input libtextstyle_cr_enc_handler_convert_input
#define cr_enc_handler_get_instance libtextstyle_cr_enc_handler_get_instance
#define cr_enc_handler_resolve_enc_alias libtextstyle_cr_enc_handler_resolve_enc_alias
#define cr_font_family_append libtextstyle_cr_font_family_append
#define cr_font_family_destroy libtextstyle_cr_font_family_destroy
#define cr_font_family_new libtextstyle_cr_font_family_new
#define cr_font_family_prepend libtextstyle_cr_font_family_prepend
#define cr_font_family_set_name libtextstyle_cr_font_family_set_name
#define cr_font_family_to_string libtextstyle_cr_font_family_to_string
#define cr_font_size_adjust_destroy libtextstyle_cr_font_size_adjust_destroy
#define cr_font_size_adjust_new libtextstyle_cr_font_size_adjust_new
#define cr_font_size_adjust_to_string libtextstyle_cr_font_size_adjust_to_string
#define cr_font_size_clear libtextstyle_cr_font_size_clear
#define cr_font_size_copy libtextstyle_cr_font_size_copy
#define cr_font_size_destroy libtextstyle_cr_font_size_destroy
#define cr_font_size_get_larger_predefined_font_size libtextstyle_cr_font_size_get_larger_predefined_font_size
#define cr_font_size_get_smaller_predefined_font_size libtextstyle_cr_font_size_get_smaller_predefined_font_size
#define cr_font_size_is_predefined_absolute_font_size libtextstyle_cr_font_size_is_predefined_absolute_font_size
#define cr_font_size_is_set_to_inherit libtextstyle_cr_font_size_is_set_to_inherit
#define cr_font_size_new libtextstyle_cr_font_size_new
#define cr_font_size_set_absolute_font_size libtextstyle_cr_font_size_set_absolute_font_size
#define cr_font_size_set_predefined_absolute_font_size libtextstyle_cr_font_size_set_predefined_absolute_font_size
#define cr_font_size_set_relative_font_size libtextstyle_cr_font_size_set_relative_font_size
#define cr_font_size_set_to_inherit libtextstyle_cr_font_size_set_to_inherit
#define cr_font_size_to_string libtextstyle_cr_font_size_to_string
#define cr_font_stretch_to_string libtextstyle_cr_font_stretch_to_string
#define cr_font_style_to_string libtextstyle_cr_font_style_to_string
#define cr_font_variant_to_string libtextstyle_cr_font_variant_to_string
#define cr_font_weight_get_bolder libtextstyle_cr_font_weight_get_bolder
#define cr_font_weight_to_string libtextstyle_cr_font_weight_to_string
#define cr_input_consume_char libtextstyle_cr_input_consume_char
#define cr_input_consume_chars libtextstyle_cr_input_consume_chars
#define cr_input_consume_white_spaces libtextstyle_cr_input_consume_white_spaces
#define cr_input_destroy libtextstyle_cr_input_destroy
#define cr_input_end_of_input libtextstyle_cr_input_end_of_input
#define cr_input_get_byte_addr libtextstyle_cr_input_get_byte_addr
#define cr_input_get_column_num libtextstyle_cr_input_get_column_num
#define cr_input_get_cur_byte_addr libtextstyle_cr_input_get_cur_byte_addr
#define cr_input_get_cur_index libtextstyle_cr_input_get_cur_index
#define cr_input_get_cur_pos libtextstyle_cr_input_get_cur_pos
#define cr_input_get_end_of_file libtextstyle_cr_input_get_end_of_file
#define cr_input_get_end_of_line libtextstyle_cr_input_get_end_of_line
#define cr_input_get_line_num libtextstyle_cr_input_get_line_num
#define cr_input_get_nb_bytes_left libtextstyle_cr_input_get_nb_bytes_left
#define cr_input_get_parsing_location libtextstyle_cr_input_get_parsing_location
#define cr_input_increment_col_num libtextstyle_cr_input_increment_col_num
#define cr_input_increment_line_num libtextstyle_cr_input_increment_line_num
#define cr_input_new_from_buf libtextstyle_cr_input_new_from_buf
#define cr_input_new_from_uri libtextstyle_cr_input_new_from_uri
#define cr_input_peek_byte libtextstyle_cr_input_peek_byte
#define cr_input_peek_byte2 libtextstyle_cr_input_peek_byte2
#define cr_input_peek_char libtextstyle_cr_input_peek_char
#define cr_input_read_byte libtextstyle_cr_input_read_byte
#define cr_input_read_char libtextstyle_cr_input_read_char
#define cr_input_ref libtextstyle_cr_input_ref
#define cr_input_seek_index libtextstyle_cr_input_seek_index
#define cr_input_set_column_num libtextstyle_cr_input_set_column_num
#define cr_input_set_cur_index libtextstyle_cr_input_set_cur_index
#define cr_input_set_cur_pos libtextstyle_cr_input_set_cur_pos
#define cr_input_set_end_of_file libtextstyle_cr_input_set_end_of_file
#define cr_input_set_end_of_line libtextstyle_cr_input_set_end_of_line
#define cr_input_set_line_num libtextstyle_cr_input_set_line_num
#define cr_input_unref libtextstyle_cr_input_unref
#define cr_num_copy libtextstyle_cr_num_copy
#define cr_num_destroy libtextstyle_cr_num_destroy
#define cr_num_dup libtextstyle_cr_num_dup
#define cr_num_is_fixed_length libtextstyle_cr_num_is_fixed_length
#define cr_num_new libtextstyle_cr_num_new
#define cr_num_new_with_val libtextstyle_cr_num_new_with_val
#define cr_num_set libtextstyle_cr_num_set
#define cr_num_to_string libtextstyle_cr_num_to_string
#define cr_om_parser_destroy libtextstyle_cr_om_parser_destroy
#define cr_om_parser_new libtextstyle_cr_om_parser_new
#define cr_om_parser_parse_buf libtextstyle_cr_om_parser_parse_buf
#define cr_om_parser_parse_file libtextstyle_cr_om_parser_parse_file
#define cr_om_parser_parse_paths_to_cascade libtextstyle_cr_om_parser_parse_paths_to_cascade
#define cr_om_parser_simply_parse_buf libtextstyle_cr_om_parser_simply_parse_buf
#define cr_om_parser_simply_parse_file libtextstyle_cr_om_parser_simply_parse_file
#define cr_om_parser_simply_parse_paths_to_cascade libtextstyle_cr_om_parser_simply_parse_paths_to_cascade
#define cr_parser_destroy libtextstyle_cr_parser_destroy
#define cr_parser_get_parsing_location libtextstyle_cr_parser_get_parsing_location
#define cr_parser_get_sac_handler libtextstyle_cr_parser_get_sac_handler
#define cr_parser_get_tknzr libtextstyle_cr_parser_get_tknzr
#define cr_parser_get_use_core_grammar libtextstyle_cr_parser_get_use_core_grammar
#define cr_parser_new libtextstyle_cr_parser_new
#define cr_parser_new_from_buf libtextstyle_cr_parser_new_from_buf
#define cr_parser_new_from_file libtextstyle_cr_parser_new_from_file
#define cr_parser_new_from_input libtextstyle_cr_parser_new_from_input
#define cr_parser_parse libtextstyle_cr_parser_parse
#define cr_parser_parse_buf libtextstyle_cr_parser_parse_buf
#define cr_parser_parse_charset libtextstyle_cr_parser_parse_charset
#define cr_parser_parse_declaration libtextstyle_cr_parser_parse_declaration
#define cr_parser_parse_expr libtextstyle_cr_parser_parse_expr
#define cr_parser_parse_file libtextstyle_cr_parser_parse_file
#define cr_parser_parse_font_face libtextstyle_cr_parser_parse_font_face
#define cr_parser_parse_import libtextstyle_cr_parser_parse_import
#define cr_parser_parse_media libtextstyle_cr_parser_parse_media
#define cr_parser_parse_page libtextstyle_cr_parser_parse_page
#define cr_parser_parse_prio libtextstyle_cr_parser_parse_prio
#define cr_parser_parse_ruleset libtextstyle_cr_parser_parse_ruleset
#define cr_parser_parse_statement_core libtextstyle_cr_parser_parse_statement_core
#define cr_parser_parse_term libtextstyle_cr_parser_parse_term
#define cr_parser_set_default_sac_handler libtextstyle_cr_parser_set_default_sac_handler
#define cr_parser_set_sac_handler libtextstyle_cr_parser_set_sac_handler
#define cr_parser_set_tknzr libtextstyle_cr_parser_set_tknzr
#define cr_parser_set_use_core_grammar libtextstyle_cr_parser_set_use_core_grammar
#define cr_parser_try_to_skip_spaces_and_comments libtextstyle_cr_parser_try_to_skip_spaces_and_comments
#define cr_parsing_location_copy libtextstyle_cr_parsing_location_copy
#define cr_parsing_location_destroy libtextstyle_cr_parsing_location_destroy
#define cr_parsing_location_dump libtextstyle_cr_parsing_location_dump
#define cr_parsing_location_init libtextstyle_cr_parsing_location_init
#define cr_parsing_location_new libtextstyle_cr_parsing_location_new
#define cr_parsing_location_to_string libtextstyle_cr_parsing_location_to_string
#define cr_prop_list_append libtextstyle_cr_prop_list_append
#define cr_prop_list_append2 libtextstyle_cr_prop_list_append2
#define cr_prop_list_destroy libtextstyle_cr_prop_list_destroy
#define cr_prop_list_get_decl libtextstyle_cr_prop_list_get_decl
#define cr_prop_list_get_next libtextstyle_cr_prop_list_get_next
#define cr_prop_list_get_prev libtextstyle_cr_prop_list_get_prev
#define cr_prop_list_get_prop libtextstyle_cr_prop_list_get_prop
#define cr_prop_list_lookup_prop libtextstyle_cr_prop_list_lookup_prop
#define cr_prop_list_prepend libtextstyle_cr_prop_list_prepend
#define cr_prop_list_prepend2 libtextstyle_cr_prop_list_prepend2
#define cr_prop_list_set_decl libtextstyle_cr_prop_list_set_decl
#define cr_prop_list_set_prop libtextstyle_cr_prop_list_set_prop
#define cr_prop_list_unlink libtextstyle_cr_prop_list_unlink
#define cr_pseudo_destroy libtextstyle_cr_pseudo_destroy
#define cr_pseudo_dump libtextstyle_cr_pseudo_dump
#define cr_pseudo_new libtextstyle_cr_pseudo_new
#define cr_pseudo_to_string libtextstyle_cr_pseudo_to_string
#define cr_rgb_compute_from_percentage libtextstyle_cr_rgb_compute_from_percentage
#define cr_rgb_copy libtextstyle_cr_rgb_copy
#define cr_rgb_destroy libtextstyle_cr_rgb_destroy
#define cr_rgb_dump libtextstyle_cr_rgb_dump
#define cr_rgb_is_set_to_inherit libtextstyle_cr_rgb_is_set_to_inherit
#define cr_rgb_is_set_to_transparent libtextstyle_cr_rgb_is_set_to_transparent
#define cr_rgb_new libtextstyle_cr_rgb_new
#define cr_rgb_new_with_vals libtextstyle_cr_rgb_new_with_vals
#define cr_rgb_parse_from_buf libtextstyle_cr_rgb_parse_from_buf
#define cr_rgb_set libtextstyle_cr_rgb_set
#define cr_rgb_set_from_hex_str libtextstyle_cr_rgb_set_from_hex_str
#define cr_rgb_set_from_name libtextstyle_cr_rgb_set_from_name
#define cr_rgb_set_from_rgb libtextstyle_cr_rgb_set_from_rgb
#define cr_rgb_set_from_term libtextstyle_cr_rgb_set_from_term
#define cr_rgb_set_to_inherit libtextstyle_cr_rgb_set_to_inherit
#define cr_rgb_set_to_transparent libtextstyle_cr_rgb_set_to_transparent
#define cr_rgb_to_string libtextstyle_cr_rgb_to_string
#define cr_sel_eng_destroy libtextstyle_cr_sel_eng_destroy
#define cr_sel_eng_get_matched_properties_from_cascade libtextstyle_cr_sel_eng_get_matched_properties_from_cascade
#define cr_sel_eng_get_matched_rulesets libtextstyle_cr_sel_eng_get_matched_rulesets
#define cr_sel_eng_get_matched_style libtextstyle_cr_sel_eng_get_matched_style
#define cr_sel_eng_get_pseudo_class_selector_handler libtextstyle_cr_sel_eng_get_pseudo_class_selector_handler
#define cr_sel_eng_matches_node libtextstyle_cr_sel_eng_matches_node
#define cr_sel_eng_new libtextstyle_cr_sel_eng_new
#define cr_sel_eng_register_pseudo_class_sel_handler libtextstyle_cr_sel_eng_register_pseudo_class_sel_handler
#define cr_sel_eng_unregister_all_pseudo_class_sel_handlers libtextstyle_cr_sel_eng_unregister_all_pseudo_class_sel_handlers
#define cr_sel_eng_unregister_pseudo_class_sel_handler libtextstyle_cr_sel_eng_unregister_pseudo_class_sel_handler
#define cr_selector_append libtextstyle_cr_selector_append
#define cr_selector_append_simple_sel libtextstyle_cr_selector_append_simple_sel
#define cr_selector_destroy libtextstyle_cr_selector_destroy
#define cr_selector_dump libtextstyle_cr_selector_dump
#define cr_selector_new libtextstyle_cr_selector_new
#define cr_selector_parse_from_buf libtextstyle_cr_selector_parse_from_buf
#define cr_selector_prepend libtextstyle_cr_selector_prepend
#define cr_selector_ref libtextstyle_cr_selector_ref
#define cr_selector_to_string libtextstyle_cr_selector_to_string
#define cr_selector_unref libtextstyle_cr_selector_unref
#define cr_simple_sel_append_simple_sel libtextstyle_cr_simple_sel_append_simple_sel
#define cr_simple_sel_compute_specificity libtextstyle_cr_simple_sel_compute_specificity
#define cr_simple_sel_destroy libtextstyle_cr_simple_sel_destroy
#define cr_simple_sel_dump libtextstyle_cr_simple_sel_dump
#define cr_simple_sel_new libtextstyle_cr_simple_sel_new
#define cr_simple_sel_one_to_string libtextstyle_cr_simple_sel_one_to_string
#define cr_simple_sel_prepend_simple_sel libtextstyle_cr_simple_sel_prepend_simple_sel
#define cr_simple_sel_to_string libtextstyle_cr_simple_sel_to_string
#define cr_statement_append libtextstyle_cr_statement_append
#define cr_statement_at_charset_rule_get_charset libtextstyle_cr_statement_at_charset_rule_get_charset
#define cr_statement_at_charset_rule_parse_from_buf libtextstyle_cr_statement_at_charset_rule_parse_from_buf
#define cr_statement_at_charset_rule_set_charset libtextstyle_cr_statement_at_charset_rule_set_charset
#define cr_statement_at_font_face_rule_add_decl libtextstyle_cr_statement_at_font_face_rule_add_decl
#define cr_statement_at_font_face_rule_get_decls libtextstyle_cr_statement_at_font_face_rule_get_decls
#define cr_statement_at_font_face_rule_set_decls libtextstyle_cr_statement_at_font_face_rule_set_decls
#define cr_statement_at_import_rule_get_imported_sheet libtextstyle_cr_statement_at_import_rule_get_imported_sheet
#define cr_statement_at_import_rule_get_url libtextstyle_cr_statement_at_import_rule_get_url
#define cr_statement_at_import_rule_parse_from_buf libtextstyle_cr_statement_at_import_rule_parse_from_buf
#define cr_statement_at_import_rule_set_imported_sheet libtextstyle_cr_statement_at_import_rule_set_imported_sheet
#define cr_statement_at_import_rule_set_url libtextstyle_cr_statement_at_import_rule_set_url
#define cr_statement_at_media_get_from_list libtextstyle_cr_statement_at_media_get_from_list
#define cr_statement_at_media_nr_rules libtextstyle_cr_statement_at_media_nr_rules
#define cr_statement_at_media_rule_parse_from_buf libtextstyle_cr_statement_at_media_rule_parse_from_buf
#define cr_statement_at_page_rule_get_declarations libtextstyle_cr_statement_at_page_rule_get_declarations
#define cr_statement_at_page_rule_parse_from_buf libtextstyle_cr_statement_at_page_rule_parse_from_buf
#define cr_statement_at_page_rule_set_declarations libtextstyle_cr_statement_at_page_rule_set_declarations
#define cr_statement_destroy libtextstyle_cr_statement_destroy
#define cr_statement_does_buf_parses_against_core libtextstyle_cr_statement_does_buf_parses_against_core
#define cr_statement_dump libtextstyle_cr_statement_dump
#define cr_statement_dump_charset libtextstyle_cr_statement_dump_charset
#define cr_statement_dump_font_face_rule libtextstyle_cr_statement_dump_font_face_rule
#define cr_statement_dump_import_rule libtextstyle_cr_statement_dump_import_rule
#define cr_statement_dump_media_rule libtextstyle_cr_statement_dump_media_rule
#define cr_statement_dump_page libtextstyle_cr_statement_dump_page
#define cr_statement_dump_ruleset libtextstyle_cr_statement_dump_ruleset
#define cr_statement_font_face_rule_parse_from_buf libtextstyle_cr_statement_font_face_rule_parse_from_buf
#define cr_statement_get_from_list libtextstyle_cr_statement_get_from_list
#define cr_statement_get_parent_sheet libtextstyle_cr_statement_get_parent_sheet
#define cr_statement_list_to_string libtextstyle_cr_statement_list_to_string
#define cr_statement_new_at_charset_rule libtextstyle_cr_statement_new_at_charset_rule
#define cr_statement_new_at_font_face_rule libtextstyle_cr_statement_new_at_font_face_rule
#define cr_statement_new_at_import_rule libtextstyle_cr_statement_new_at_import_rule
#define cr_statement_new_at_media_rule libtextstyle_cr_statement_new_at_media_rule
#define cr_statement_new_at_page_rule libtextstyle_cr_statement_new_at_page_rule
#define cr_statement_new_ruleset libtextstyle_cr_statement_new_ruleset
#define cr_statement_nr_rules libtextstyle_cr_statement_nr_rules
#define cr_statement_parse_from_buf libtextstyle_cr_statement_parse_from_buf
#define cr_statement_prepend libtextstyle_cr_statement_prepend
#define cr_statement_ruleset_append_decl libtextstyle_cr_statement_ruleset_append_decl
#define cr_statement_ruleset_append_decl2 libtextstyle_cr_statement_ruleset_append_decl2
#define cr_statement_ruleset_get_declarations libtextstyle_cr_statement_ruleset_get_declarations
#define cr_statement_ruleset_get_sel_list libtextstyle_cr_statement_ruleset_get_sel_list
#define cr_statement_ruleset_parse_from_buf libtextstyle_cr_statement_ruleset_parse_from_buf
#define cr_statement_ruleset_set_decl_list libtextstyle_cr_statement_ruleset_set_decl_list
#define cr_statement_ruleset_set_sel_list libtextstyle_cr_statement_ruleset_set_sel_list
#define cr_statement_set_parent_sheet libtextstyle_cr_statement_set_parent_sheet
#define cr_statement_to_string libtextstyle_cr_statement_to_string
#define cr_statement_unlink libtextstyle_cr_statement_unlink
#define cr_string_destroy libtextstyle_cr_string_destroy
#define cr_string_dup libtextstyle_cr_string_dup
#define cr_string_dup2 libtextstyle_cr_string_dup2
#define cr_string_new libtextstyle_cr_string_new
#define cr_string_new_from_gstring libtextstyle_cr_string_new_from_gstring
#define cr_string_new_from_string libtextstyle_cr_string_new_from_string
#define cr_string_peek_raw_str libtextstyle_cr_string_peek_raw_str
#define cr_string_peek_raw_str_len libtextstyle_cr_string_peek_raw_str_len
#define cr_style_border_style_to_string libtextstyle_cr_style_border_style_to_string
#define cr_style_copy libtextstyle_cr_style_copy
#define cr_style_destroy libtextstyle_cr_style_destroy
#define cr_style_display_type_to_string libtextstyle_cr_style_display_type_to_string
#define cr_style_dup libtextstyle_cr_style_dup
#define cr_style_float_type_to_string libtextstyle_cr_style_float_type_to_string
#define cr_style_new libtextstyle_cr_style_new
#define cr_style_num_prop_val_to_string libtextstyle_cr_style_num_prop_val_to_string
#define cr_style_position_type_to_string libtextstyle_cr_style_position_type_to_string
#define cr_style_ref libtextstyle_cr_style_ref
#define cr_style_resolve_inherited_properties libtextstyle_cr_style_resolve_inherited_properties
#define cr_style_rgb_prop_val_to_string libtextstyle_cr_style_rgb_prop_val_to_string
#define cr_style_set_props_to_default_values libtextstyle_cr_style_set_props_to_default_values
#define cr_style_set_props_to_initial_values libtextstyle_cr_style_set_props_to_initial_values
#define cr_style_set_style_from_decl libtextstyle_cr_style_set_style_from_decl
#define cr_style_to_string libtextstyle_cr_style_to_string
#define cr_style_unref libtextstyle_cr_style_unref
#define cr_style_white_space_type_to_string libtextstyle_cr_style_white_space_type_to_string
#define cr_stylesheet_destroy libtextstyle_cr_stylesheet_destroy
#define cr_stylesheet_dump libtextstyle_cr_stylesheet_dump
#define cr_stylesheet_new libtextstyle_cr_stylesheet_new
#define cr_stylesheet_nr_rules libtextstyle_cr_stylesheet_nr_rules
#define cr_stylesheet_ref libtextstyle_cr_stylesheet_ref
#define cr_stylesheet_statement_get_from_list libtextstyle_cr_stylesheet_statement_get_from_list
#define cr_stylesheet_to_string libtextstyle_cr_stylesheet_to_string
#define cr_stylesheet_unref libtextstyle_cr_stylesheet_unref
#define cr_term_append_term libtextstyle_cr_term_append_term
#define cr_term_destroy libtextstyle_cr_term_destroy
#define cr_term_dump libtextstyle_cr_term_dump
#define cr_term_get_from_list libtextstyle_cr_term_get_from_list
#define cr_term_new libtextstyle_cr_term_new
#define cr_term_nr_values libtextstyle_cr_term_nr_values
#define cr_term_one_to_string libtextstyle_cr_term_one_to_string
#define cr_term_parse_expression_from_buf libtextstyle_cr_term_parse_expression_from_buf
#define cr_term_prepend_term libtextstyle_cr_term_prepend_term
#define cr_term_ref libtextstyle_cr_term_ref
#define cr_term_set_function libtextstyle_cr_term_set_function
#define cr_term_set_hash libtextstyle_cr_term_set_hash
#define cr_term_set_ident libtextstyle_cr_term_set_ident
#define cr_term_set_number libtextstyle_cr_term_set_number
#define cr_term_set_rgb libtextstyle_cr_term_set_rgb
#define cr_term_set_string libtextstyle_cr_term_set_string
#define cr_term_set_uri libtextstyle_cr_term_set_uri
#define cr_term_to_string libtextstyle_cr_term_to_string
#define cr_term_unref libtextstyle_cr_term_unref
#define cr_tknzr_consume_chars libtextstyle_cr_tknzr_consume_chars
#define cr_tknzr_destroy libtextstyle_cr_tknzr_destroy
#define cr_tknzr_get_cur_byte_addr libtextstyle_cr_tknzr_get_cur_byte_addr
#define cr_tknzr_get_cur_pos libtextstyle_cr_tknzr_get_cur_pos
#define cr_tknzr_get_input libtextstyle_cr_tknzr_get_input
#define cr_tknzr_get_nb_bytes_left libtextstyle_cr_tknzr_get_nb_bytes_left
#define cr_tknzr_get_next_token libtextstyle_cr_tknzr_get_next_token
#define cr_tknzr_get_parsing_location libtextstyle_cr_tknzr_get_parsing_location
#define cr_tknzr_new libtextstyle_cr_tknzr_new
#define cr_tknzr_new_from_buf libtextstyle_cr_tknzr_new_from_buf
#define cr_tknzr_new_from_uri libtextstyle_cr_tknzr_new_from_uri
#define cr_tknzr_parse_token libtextstyle_cr_tknzr_parse_token
#define cr_tknzr_peek_byte libtextstyle_cr_tknzr_peek_byte
#define cr_tknzr_peek_byte2 libtextstyle_cr_tknzr_peek_byte2
#define cr_tknzr_peek_char libtextstyle_cr_tknzr_peek_char
#define cr_tknzr_read_byte libtextstyle_cr_tknzr_read_byte
#define cr_tknzr_read_char libtextstyle_cr_tknzr_read_char
#define cr_tknzr_ref libtextstyle_cr_tknzr_ref
#define cr_tknzr_seek_index libtextstyle_cr_tknzr_seek_index
#define cr_tknzr_set_cur_pos libtextstyle_cr_tknzr_set_cur_pos
#define cr_tknzr_set_input libtextstyle_cr_tknzr_set_input
#define cr_tknzr_unget_token libtextstyle_cr_tknzr_unget_token
#define cr_tknzr_unref libtextstyle_cr_tknzr_unref
#define cr_token_destroy libtextstyle_cr_token_destroy
#define cr_token_new libtextstyle_cr_token_new
#define cr_token_set_angle libtextstyle_cr_token_set_angle
#define cr_token_set_atkeyword libtextstyle_cr_token_set_atkeyword
#define cr_token_set_bc libtextstyle_cr_token_set_bc
#define cr_token_set_bo libtextstyle_cr_token_set_bo
#define cr_token_set_cbc libtextstyle_cr_token_set_cbc
#define cr_token_set_cbo libtextstyle_cr_token_set_cbo
#define cr_token_set_cdc libtextstyle_cr_token_set_cdc
#define cr_token_set_cdo libtextstyle_cr_token_set_cdo
#define cr_token_set_charset_sym libtextstyle_cr_token_set_charset_sym
#define cr_token_set_comment libtextstyle_cr_token_set_comment
#define cr_token_set_dashmatch libtextstyle_cr_token_set_dashmatch
#define cr_token_set_delim libtextstyle_cr_token_set_delim
#define cr_token_set_dimen libtextstyle_cr_token_set_dimen
#define cr_token_set_ems libtextstyle_cr_token_set_ems
#define cr_token_set_exs libtextstyle_cr_token_set_exs
#define cr_token_set_font_face_sym libtextstyle_cr_token_set_font_face_sym
#define cr_token_set_freq libtextstyle_cr_token_set_freq
#define cr_token_set_function libtextstyle_cr_token_set_function
#define cr_token_set_hash libtextstyle_cr_token_set_hash
#define cr_token_set_ident libtextstyle_cr_token_set_ident
#define cr_token_set_import_sym libtextstyle_cr_token_set_import_sym
#define cr_token_set_important_sym libtextstyle_cr_token_set_important_sym
#define cr_token_set_includes libtextstyle_cr_token_set_includes
#define cr_token_set_length libtextstyle_cr_token_set_length
#define cr_token_set_media_sym libtextstyle_cr_token_set_media_sym
#define cr_token_set_number libtextstyle_cr_token_set_number
#define cr_token_set_page_sym libtextstyle_cr_token_set_page_sym
#define cr_token_set_pc libtextstyle_cr_token_set_pc
#define cr_token_set_percentage libtextstyle_cr_token_set_percentage
#define cr_token_set_po libtextstyle_cr_token_set_po
#define cr_token_set_rgb libtextstyle_cr_token_set_rgb
#define cr_token_set_s libtextstyle_cr_token_set_s
#define cr_token_set_semicolon libtextstyle_cr_token_set_semicolon
#define cr_token_set_string libtextstyle_cr_token_set_string
#define cr_token_set_time libtextstyle_cr_token_set_time
#define cr_token_set_uri libtextstyle_cr_token_set_uri
#define cr_utils_dump_n_chars libtextstyle_cr_utils_dump_n_chars
#define cr_utils_dump_n_chars2 libtextstyle_cr_utils_dump_n_chars2
#define cr_utils_dup_glist_of_cr_string libtextstyle_cr_utils_dup_glist_of_cr_string
#define cr_utils_dup_glist_of_string libtextstyle_cr_utils_dup_glist_of_string
#define cr_utils_is_hexa_char libtextstyle_cr_utils_is_hexa_char
#define cr_utils_is_newline libtextstyle_cr_utils_is_newline
#define cr_utils_is_nonascii libtextstyle_cr_utils_is_nonascii
#define cr_utils_is_white_space libtextstyle_cr_utils_is_white_space
#define cr_utils_read_char_from_utf8_buf libtextstyle_cr_utils_read_char_from_utf8_buf
#define cr_utils_ucs1_str_len_as_utf8 libtextstyle_cr_utils_ucs1_str_len_as_utf8
#define cr_utils_ucs1_str_to_utf8 libtextstyle_cr_utils_ucs1_str_to_utf8
#define cr_utils_ucs1_to_utf8 libtextstyle_cr_utils_ucs1_to_utf8
#define cr_utils_ucs4_str_len_as_utf8 libtextstyle_cr_utils_ucs4_str_len_as_utf8
#define cr_utils_ucs4_str_to_utf8 libtextstyle_cr_utils_ucs4_str_to_utf8
#define cr_utils_ucs4_to_utf8 libtextstyle_cr_utils_ucs4_to_utf8
#define cr_utils_utf8_str_len_as_ucs1 libtextstyle_cr_utils_utf8_str_len_as_ucs1
#define cr_utils_utf8_str_len_as_ucs4 libtextstyle_cr_utils_utf8_str_len_as_ucs4
#define cr_utils_utf8_str_to_ucs1 libtextstyle_cr_utils_utf8_str_to_ucs1
#define cr_utils_utf8_str_to_ucs4 libtextstyle_cr_utils_utf8_str_to_ucs4
#define cr_utils_utf8_to_ucs1 libtextstyle_cr_utils_utf8_to_ucs1
#define cr_utils_utf8_to_ucs4 libtextstyle_cr_utils_utf8_to_ucs4
#define deactivate_term_non_default_mode libtextstyle_deactivate_term_non_default_mode
#define deactivate_term_style_controller libtextstyle_deactivate_term_style_controller
#define dup_cloexec libtextstyle_dup_cloexec
#define execute_all_close_hooks libtextstyle_execute_all_close_hooks
#define execute_all_ioctl_hooks libtextstyle_execute_all_ioctl_hooks
#define execute_close_hooks libtextstyle_execute_close_hooks
#define execute_ioctl_hooks libtextstyle_execute_ioctl_hooks
#define exit_failure libtextstyle_exit_failure
#define fd_ostream_typeinfo libtextstyle_fd_ostream_typeinfo
#define fd_ostream_vtable libtextstyle_fd_ostream_vtable
#define file_ostream_typeinfo libtextstyle_file_ostream_typeinfo
#define file_ostream_vtable libtextstyle_file_ostream_vtable
#define freea libtextstyle_freea
#define full_write libtextstyle_full_write
#define g_ascii_dtostr libtextstyle_g_ascii_dtostr
#define g_ascii_formatd libtextstyle_g_ascii_formatd
#define g_ascii_strcasecmp libtextstyle_g_ascii_strcasecmp
#define g_ascii_strup libtextstyle_g_ascii_strup
#define g_ascii_table libtextstyle_g_ascii_table
#define g_ascii_toupper libtextstyle_g_ascii_toupper
#define g_hash_table_insert libtextstyle_g_hash_table_insert
#define g_hash_table_lookup libtextstyle_g_hash_table_lookup
#define g_hash_table_new libtextstyle_g_hash_table_new
#define g_hash_table_new_full libtextstyle_g_hash_table_new_full
#define g_list_append libtextstyle_g_list_append
#define g_list_delete_link libtextstyle_g_list_delete_link
#define g_list_free libtextstyle_g_list_free
#define g_list_last libtextstyle_g_list_last
#define g_list_prepend libtextstyle_g_list_prepend
#define g_log libtextstyle_g_log
#define g_printerr libtextstyle_g_printerr
#define g_spaced_primes_closest libtextstyle_g_spaced_primes_closest
#define g_stpcpy libtextstyle_g_stpcpy
#define g_str_equal libtextstyle_g_str_equal
#define g_str_hash libtextstyle_g_str_hash
#define g_strconcat libtextstyle_g_strconcat
#define g_strdup libtextstyle_g_strdup
#define g_strdup_printf libtextstyle_g_strdup_printf
#define g_strdup_vprintf libtextstyle_g_strdup_vprintf
#define g_string_append libtextstyle_g_string_append
#define g_string_append_c libtextstyle_g_string_append_c
#define g_string_append_len libtextstyle_g_string_append_len
#define g_string_append_printf libtextstyle_g_string_append_printf
#define g_string_append_unichar libtextstyle_g_string_append_unichar
#define g_string_free libtextstyle_g_string_free
#define g_string_insert_c libtextstyle_g_string_insert_c
#define g_string_insert_len libtextstyle_g_string_insert_len
#define g_string_insert_unichar libtextstyle_g_string_insert_unichar
#define g_string_new libtextstyle_g_string_new
#define g_string_new_len libtextstyle_g_string_new_len
#define g_string_sized_new libtextstyle_g_string_sized_new
#define g_strndup libtextstyle_g_strndup
#define g_strstr_len libtextstyle_g_strstr_len
#define g_warning libtextstyle_g_warning
#define get_fatal_signal_set libtextstyle_get_fatal_signal_set
#define get_fatal_signals libtextstyle_get_fatal_signals
#define get_ppid_of libtextstyle_get_ppid_of
#define get_progname_of libtextstyle_get_progname_of
#define getprogname libtextstyle_getprogname
#define gl_array_list_implementation libtextstyle_gl_array_list_implementation
#define gl_sockets_cleanup libtextstyle_gl_sockets_cleanup
#define gl_sockets_startup libtextstyle_gl_sockets_startup
#define hash_destroy libtextstyle_hash_destroy
#define hash_find_entry libtextstyle_hash_find_entry
#define hash_init libtextstyle_hash_init
#define hash_insert_entry libtextstyle_hash_insert_entry
#define hash_iterate libtextstyle_hash_iterate
#define hash_iterate_modify libtextstyle_hash_iterate_modify
#define hash_set_value libtextstyle_hash_set_value
#define html_ostream_typeinfo libtextstyle_html_ostream_typeinfo
#define html_ostream_vtable libtextstyle_html_ostream_vtable
#define html_styled_ostream_typeinfo libtextstyle_html_styled_ostream_typeinfo
#define html_styled_ostream_vtable libtextstyle_html_styled_ostream_vtable
#define iconv_ostream_typeinfo libtextstyle_iconv_ostream_typeinfo
#define iconv_ostream_vtable libtextstyle_iconv_ostream_vtable
#define initGenericErrorDefaultFunc libtextstyle_initGenericErrorDefaultFunc
#define inputPop libtextstyle_inputPop
#define inputPush libtextstyle_inputPush
#define isolat1ToUTF8 libtextstyle_isolat1ToUTF8
#define last_component libtextstyle_last_component
#define libxml_domnode_binary_insertion_sort libtextstyle_libxml_domnode_binary_insertion_sort
#define libxml_domnode_tim_sort libtextstyle_libxml_domnode_tim_sort
#define memory_ostream__contents libtextstyle_memory_ostream__contents
#define memory_ostream_typeinfo libtextstyle_memory_ostream_typeinfo
#define memory_ostream_vtable libtextstyle_memory_ostream_vtable
#define mmalloca libtextstyle_mmalloca
#define namePop libtextstyle_namePop
#define namePush libtextstyle_namePush
#define next_prime libtextstyle_next_prime
#define nodePop libtextstyle_nodePop
#define nodePush libtextstyle_nodePush
#define noop_styled_ostream_typeinfo libtextstyle_noop_styled_ostream_typeinfo
#define noop_styled_ostream_vtable libtextstyle_noop_styled_ostream_vtable
#define oldXMLWDcompatibility libtextstyle_oldXMLWDcompatibility
#define ostream__flush libtextstyle_ostream__flush
#define ostream__free libtextstyle_ostream__free
#define ostream__write_mem libtextstyle_ostream__write_mem
#define ostream_typeinfo libtextstyle_ostream_typeinfo
#define ostream_vtable libtextstyle_ostream_vtable
#define printf_frexp libtextstyle_printf_frexp
#define printf_frexpl libtextstyle_printf_frexpl
#define register_fd_hook libtextstyle_register_fd_hook
#define safe_read libtextstyle_safe_read
#define safe_write libtextstyle_safe_write
#define set_cloexec_flag libtextstyle_set_cloexec_flag
#define styled_ostream__begin_use_class libtextstyle_styled_ostream__begin_use_class
#define styled_ostream__end_use_class libtextstyle_styled_ostream__end_use_class
#define styled_ostream__flush libtextstyle_styled_ostream__flush
#define styled_ostream__flush_to_current_style libtextstyle_styled_ostream__flush_to_current_style
#define styled_ostream__free libtextstyle_styled_ostream__free
#define styled_ostream__get_hyperlink_id libtextstyle_styled_ostream__get_hyperlink_id
#define styled_ostream__get_hyperlink_ref libtextstyle_styled_ostream__get_hyperlink_ref
#define styled_ostream__set_hyperlink libtextstyle_styled_ostream__set_hyperlink
#define styled_ostream__write_mem libtextstyle_styled_ostream__write_mem
#define styled_ostream_typeinfo libtextstyle_styled_ostream_typeinfo
#define styled_ostream_vtable libtextstyle_styled_ostream_vtable
#define term_ostream_typeinfo libtextstyle_term_ostream_typeinfo
#define term_ostream_vtable libtextstyle_term_ostream_vtable
#define term_styled_ostream_typeinfo libtextstyle_term_styled_ostream_typeinfo
#define term_styled_ostream_vtable libtextstyle_term_styled_ostream_vtable
#define u8_mbtouc libtextstyle_u8_mbtouc
#define unblock_fatal_signals libtextstyle_unblock_fatal_signals
#define unregister_fd_hook libtextstyle_unregister_fd_hook
#define x2realloc libtextstyle_x2realloc
#define xalloc_die libtextstyle_xalloc_die
#define xasprintf libtextstyle_xasprintf
#define xcalloc libtextstyle_xcalloc
#define xconcatenated_filename libtextstyle_xconcatenated_filename
#define xgethostname libtextstyle_xgethostname
#define xmalloc libtextstyle_xmalloc
#define xmalloc_exit_failure libtextstyle_xmalloc_exit_failure
#define xmemdup libtextstyle_xmemdup
#define xmlAddAttributeDecl libtextstyle_xmlAddAttributeDecl
#define xmlAddChild libtextstyle_xmlAddChild
#define xmlAddChildList libtextstyle_xmlAddChildList
#define xmlAddDocEntity libtextstyle_xmlAddDocEntity
#define xmlAddDtdEntity libtextstyle_xmlAddDtdEntity
#define xmlAddElementDecl libtextstyle_xmlAddElementDecl
#define xmlAddEncodingAlias libtextstyle_xmlAddEncodingAlias
#define xmlAddID libtextstyle_xmlAddID
#define xmlAddNextSibling libtextstyle_xmlAddNextSibling
#define xmlAddNotationDecl libtextstyle_xmlAddNotationDecl
#define xmlAddPrevSibling libtextstyle_xmlAddPrevSibling
#define xmlAddRef libtextstyle_xmlAddRef
#define xmlAddSibling libtextstyle_xmlAddSibling
#define xmlAllocParserInputBuffer libtextstyle_xmlAllocParserInputBuffer
#define xmlBufAdd libtextstyle_xmlBufAdd
#define xmlBufAddHead libtextstyle_xmlBufAddHead
#define xmlBufAddLen libtextstyle_xmlBufAddLen
#define xmlBufAvail libtextstyle_xmlBufAvail
#define xmlBufBackToBuffer libtextstyle_xmlBufBackToBuffer
#define xmlBufCCat libtextstyle_xmlBufCCat
#define xmlBufCat libtextstyle_xmlBufCat
#define xmlBufContent libtextstyle_xmlBufContent
#define xmlBufCreate libtextstyle_xmlBufCreate
#define xmlBufCreateSize libtextstyle_xmlBufCreateSize
#define xmlBufCreateStatic libtextstyle_xmlBufCreateStatic
#define xmlBufDetach libtextstyle_xmlBufDetach
#define xmlBufDump libtextstyle_xmlBufDump
#define xmlBufEmpty libtextstyle_xmlBufEmpty
#define xmlBufEnd libtextstyle_xmlBufEnd
#define xmlBufErase libtextstyle_xmlBufErase
#define xmlBufFree libtextstyle_xmlBufFree
#define xmlBufFromBuffer libtextstyle_xmlBufFromBuffer
#define xmlBufGetAllocationScheme libtextstyle_xmlBufGetAllocationScheme
#define xmlBufGetInputBase libtextstyle_xmlBufGetInputBase
#define xmlBufGetNodeContent libtextstyle_xmlBufGetNodeContent
#define xmlBufGrow libtextstyle_xmlBufGrow
#define xmlBufInflate libtextstyle_xmlBufInflate
#define xmlBufIsEmpty libtextstyle_xmlBufIsEmpty
#define xmlBufLength libtextstyle_xmlBufLength
#define xmlBufMergeBuffer libtextstyle_xmlBufMergeBuffer
#define xmlBufResetInput libtextstyle_xmlBufResetInput
#define xmlBufResize libtextstyle_xmlBufResize
#define xmlBufSetAllocationScheme libtextstyle_xmlBufSetAllocationScheme
#define xmlBufSetInputBaseCur libtextstyle_xmlBufSetInputBaseCur
#define xmlBufShrink libtextstyle_xmlBufShrink
#define xmlBufUse libtextstyle_xmlBufUse
#define xmlBufWriteCHAR libtextstyle_xmlBufWriteCHAR
#define xmlBufWriteChar libtextstyle_xmlBufWriteChar
#define xmlBufWriteQuotedString libtextstyle_xmlBufWriteQuotedString
#define xmlBufferAdd libtextstyle_xmlBufferAdd
#define xmlBufferAddHead libtextstyle_xmlBufferAddHead
#define xmlBufferAllocScheme libtextstyle_xmlBufferAllocScheme
#define xmlBufferCCat libtextstyle_xmlBufferCCat
#define xmlBufferCat libtextstyle_xmlBufferCat
#define xmlBufferContent libtextstyle_xmlBufferContent
#define xmlBufferCreate libtextstyle_xmlBufferCreate
#define xmlBufferCreateSize libtextstyle_xmlBufferCreateSize
#define xmlBufferCreateStatic libtextstyle_xmlBufferCreateStatic
#define xmlBufferDetach libtextstyle_xmlBufferDetach
#define xmlBufferDump libtextstyle_xmlBufferDump
#define xmlBufferEmpty libtextstyle_xmlBufferEmpty
#define xmlBufferFree libtextstyle_xmlBufferFree
#define xmlBufferGrow libtextstyle_xmlBufferGrow
#define xmlBufferLength libtextstyle_xmlBufferLength
#define xmlBufferResize libtextstyle_xmlBufferResize
#define xmlBufferSetAllocationScheme libtextstyle_xmlBufferSetAllocationScheme
#define xmlBufferShrink libtextstyle_xmlBufferShrink
#define xmlBufferWriteCHAR libtextstyle_xmlBufferWriteCHAR
#define xmlBufferWriteChar libtextstyle_xmlBufferWriteChar
#define xmlBufferWriteQuotedString libtextstyle_xmlBufferWriteQuotedString
#define xmlBuildQName libtextstyle_xmlBuildQName
#define xmlBuildRelativeURI libtextstyle_xmlBuildRelativeURI
#define xmlBuildURI libtextstyle_xmlBuildURI
#define xmlByteConsumed libtextstyle_xmlByteConsumed
#define xmlCanonicPath libtextstyle_xmlCanonicPath
#define xmlCharEncCloseFunc libtextstyle_xmlCharEncCloseFunc
#define xmlCharEncFirstLine libtextstyle_xmlCharEncFirstLine
#define xmlCharEncFirstLineInput libtextstyle_xmlCharEncFirstLineInput
#define xmlCharEncFirstLineInt libtextstyle_xmlCharEncFirstLineInt
#define xmlCharEncInFunc libtextstyle_xmlCharEncInFunc
#define xmlCharEncInput libtextstyle_xmlCharEncInput
#define xmlCharEncOutFunc libtextstyle_xmlCharEncOutFunc
#define xmlCharInRange libtextstyle_xmlCharInRange
#define xmlCharStrdup libtextstyle_xmlCharStrdup
#define xmlCharStrndup libtextstyle_xmlCharStrndup
#define xmlCheckFilename libtextstyle_xmlCheckFilename
#define xmlCheckHTTPInput libtextstyle_xmlCheckHTTPInput
#define xmlCheckLanguageID libtextstyle_xmlCheckLanguageID
#define xmlCheckUTF8 libtextstyle_xmlCheckUTF8
#define xmlCheckVersion libtextstyle_xmlCheckVersion
#define xmlChildElementCount libtextstyle_xmlChildElementCount
#define xmlCleanupCharEncodingHandlers libtextstyle_xmlCleanupCharEncodingHandlers
#define xmlCleanupEncodingAliases libtextstyle_xmlCleanupEncodingAliases
#define xmlCleanupGlobals libtextstyle_xmlCleanupGlobals
#define xmlCleanupInputCallbacks libtextstyle_xmlCleanupInputCallbacks
#define xmlCleanupMemory libtextstyle_xmlCleanupMemory
#define xmlCleanupParser libtextstyle_xmlCleanupParser
#define xmlCleanupThreads libtextstyle_xmlCleanupThreads
#define xmlClearNodeInfoSeq libtextstyle_xmlClearNodeInfoSeq
#define xmlClearParserCtxt libtextstyle_xmlClearParserCtxt
#define xmlCopyAttributeTable libtextstyle_xmlCopyAttributeTable
#define xmlCopyChar libtextstyle_xmlCopyChar
#define xmlCopyCharMultiByte libtextstyle_xmlCopyCharMultiByte
#define xmlCopyDoc libtextstyle_xmlCopyDoc
#define xmlCopyDocElementContent libtextstyle_xmlCopyDocElementContent
#define xmlCopyDtd libtextstyle_xmlCopyDtd
#define xmlCopyElementContent libtextstyle_xmlCopyElementContent
#define xmlCopyElementTable libtextstyle_xmlCopyElementTable
#define xmlCopyEntitiesTable libtextstyle_xmlCopyEntitiesTable
#define xmlCopyEnumeration libtextstyle_xmlCopyEnumeration
#define xmlCopyError libtextstyle_xmlCopyError
#define xmlCopyNamespace libtextstyle_xmlCopyNamespace
#define xmlCopyNamespaceList libtextstyle_xmlCopyNamespaceList
#define xmlCopyNode libtextstyle_xmlCopyNode
#define xmlCopyNodeList libtextstyle_xmlCopyNodeList
#define xmlCopyNotationTable libtextstyle_xmlCopyNotationTable
#define xmlCopyProp libtextstyle_xmlCopyProp
#define xmlCopyPropList libtextstyle_xmlCopyPropList
#define xmlCreateDocParserCtxt libtextstyle_xmlCreateDocParserCtxt
#define xmlCreateEntitiesTable libtextstyle_xmlCreateEntitiesTable
#define xmlCreateEntityParserCtxt libtextstyle_xmlCreateEntityParserCtxt
#define xmlCreateEnumeration libtextstyle_xmlCreateEnumeration
#define xmlCreateFileParserCtxt libtextstyle_xmlCreateFileParserCtxt
#define xmlCreateIOParserCtxt libtextstyle_xmlCreateIOParserCtxt
#define xmlCreateIntSubset libtextstyle_xmlCreateIntSubset
#define xmlCreateMemoryParserCtxt libtextstyle_xmlCreateMemoryParserCtxt
#define xmlCreateURI libtextstyle_xmlCreateURI
#define xmlCreateURLParserCtxt libtextstyle_xmlCreateURLParserCtxt
#define xmlCtxtGetLastError libtextstyle_xmlCtxtGetLastError
#define xmlCtxtReadDoc libtextstyle_xmlCtxtReadDoc
#define xmlCtxtReadFd libtextstyle_xmlCtxtReadFd
#define xmlCtxtReadFile libtextstyle_xmlCtxtReadFile
#define xmlCtxtReadIO libtextstyle_xmlCtxtReadIO
#define xmlCtxtReadMemory libtextstyle_xmlCtxtReadMemory
#define xmlCtxtReset libtextstyle_xmlCtxtReset
#define xmlCtxtResetLastError libtextstyle_xmlCtxtResetLastError
#define xmlCtxtResetPush libtextstyle_xmlCtxtResetPush
#define xmlCtxtUseOptions libtextstyle_xmlCtxtUseOptions
#define xmlCurrentChar libtextstyle_xmlCurrentChar
#define xmlDOMWrapAdoptNode libtextstyle_xmlDOMWrapAdoptNode
#define xmlDOMWrapCloneNode libtextstyle_xmlDOMWrapCloneNode
#define xmlDOMWrapFreeCtxt libtextstyle_xmlDOMWrapFreeCtxt
#define xmlDOMWrapNewCtxt libtextstyle_xmlDOMWrapNewCtxt
#define xmlDOMWrapReconcileNamespaces libtextstyle_xmlDOMWrapReconcileNamespaces
#define xmlDOMWrapRemoveNode libtextstyle_xmlDOMWrapRemoveNode
#define xmlDefaultBufferSize libtextstyle_xmlDefaultBufferSize
#define xmlDefaultSAXHandlerInit libtextstyle_xmlDefaultSAXHandlerInit
#define xmlDefaultSAXLocator libtextstyle_xmlDefaultSAXLocator
#define xmlDelEncodingAlias libtextstyle_xmlDelEncodingAlias
#define xmlDeregisterNodeDefault libtextstyle_xmlDeregisterNodeDefault
#define xmlDeregisterNodeDefaultValue libtextstyle_xmlDeregisterNodeDefaultValue
#define xmlDetectCharEncoding libtextstyle_xmlDetectCharEncoding
#define xmlDictCleanup libtextstyle_xmlDictCleanup
#define xmlDictCreate libtextstyle_xmlDictCreate
#define xmlDictCreateSub libtextstyle_xmlDictCreateSub
#define xmlDictExists libtextstyle_xmlDictExists
#define xmlDictFree libtextstyle_xmlDictFree
#define xmlDictGetUsage libtextstyle_xmlDictGetUsage
#define xmlDictLookup libtextstyle_xmlDictLookup
#define xmlDictOwns libtextstyle_xmlDictOwns
#define xmlDictQLookup libtextstyle_xmlDictQLookup
#define xmlDictReference libtextstyle_xmlDictReference
#define xmlDictSetLimit libtextstyle_xmlDictSetLimit
#define xmlDictSize libtextstyle_xmlDictSize
#define xmlDoValidityCheckingDefaultValue libtextstyle_xmlDoValidityCheckingDefaultValue
#define xmlDocCopyNode libtextstyle_xmlDocCopyNode
#define xmlDocCopyNodeList libtextstyle_xmlDocCopyNodeList
#define xmlDocGetRootElement libtextstyle_xmlDocGetRootElement
#define xmlDocSetRootElement libtextstyle_xmlDocSetRootElement
#define xmlEncodeAttributeEntities libtextstyle_xmlEncodeAttributeEntities
#define xmlEncodeEntitiesReentrant libtextstyle_xmlEncodeEntitiesReentrant
#define xmlEncodeSpecialChars libtextstyle_xmlEncodeSpecialChars
#define xmlErrMemory libtextstyle_xmlErrMemory
#define xmlEscapeFormatString libtextstyle_xmlEscapeFormatString
#define xmlFileClose libtextstyle_xmlFileClose
#define xmlFileMatch libtextstyle_xmlFileMatch
#define xmlFileOpen libtextstyle_xmlFileOpen
#define xmlFileRead libtextstyle_xmlFileRead
#define xmlFindCharEncodingHandler libtextstyle_xmlFindCharEncodingHandler
#define xmlFirstElementChild libtextstyle_xmlFirstElementChild
#define xmlFree libtextstyle_xmlFree
#define xmlFreeAttributeTable libtextstyle_xmlFreeAttributeTable
#define xmlFreeDoc libtextstyle_xmlFreeDoc
#define xmlFreeDocElementContent libtextstyle_xmlFreeDocElementContent
#define xmlFreeDtd libtextstyle_xmlFreeDtd
#define xmlFreeElementContent libtextstyle_xmlFreeElementContent
#define xmlFreeElementTable libtextstyle_xmlFreeElementTable
#define xmlFreeEntitiesTable libtextstyle_xmlFreeEntitiesTable
#define xmlFreeEnumeration libtextstyle_xmlFreeEnumeration
#define xmlFreeIDTable libtextstyle_xmlFreeIDTable
#define xmlFreeInputStream libtextstyle_xmlFreeInputStream
#define xmlFreeMutex libtextstyle_xmlFreeMutex
#define xmlFreeNode libtextstyle_xmlFreeNode
#define xmlFreeNodeList libtextstyle_xmlFreeNodeList
#define xmlFreeNotationTable libtextstyle_xmlFreeNotationTable
#define xmlFreeNs libtextstyle_xmlFreeNs
#define xmlFreeNsList libtextstyle_xmlFreeNsList
#define xmlFreeParserCtxt libtextstyle_xmlFreeParserCtxt
#define xmlFreeParserInputBuffer libtextstyle_xmlFreeParserInputBuffer
#define xmlFreeProp libtextstyle_xmlFreeProp
#define xmlFreePropList libtextstyle_xmlFreePropList
#define xmlFreeRMutex libtextstyle_xmlFreeRMutex
#define xmlFreeRefTable libtextstyle_xmlFreeRefTable
#define xmlFreeURI libtextstyle_xmlFreeURI
#define xmlGcMemGet libtextstyle_xmlGcMemGet
#define xmlGcMemSetup libtextstyle_xmlGcMemSetup
#define xmlGenericError libtextstyle_xmlGenericError
#define xmlGenericErrorContext libtextstyle_xmlGenericErrorContext
#define xmlGenericErrorDefaultFunc libtextstyle_xmlGenericErrorDefaultFunc
#define xmlGetBufferAllocationScheme libtextstyle_xmlGetBufferAllocationScheme
#define xmlGetCharEncodingHandler libtextstyle_xmlGetCharEncodingHandler
#define xmlGetCharEncodingName libtextstyle_xmlGetCharEncodingName
#define xmlGetCompressMode libtextstyle_xmlGetCompressMode
#define xmlGetDocCompressMode libtextstyle_xmlGetDocCompressMode
#define xmlGetDocEntity libtextstyle_xmlGetDocEntity
#define xmlGetDtdAttrDesc libtextstyle_xmlGetDtdAttrDesc
#define xmlGetDtdElementDesc libtextstyle_xmlGetDtdElementDesc
#define xmlGetDtdEntity libtextstyle_xmlGetDtdEntity
#define xmlGetDtdNotationDesc libtextstyle_xmlGetDtdNotationDesc
#define xmlGetDtdQAttrDesc libtextstyle_xmlGetDtdQAttrDesc
#define xmlGetDtdQElementDesc libtextstyle_xmlGetDtdQElementDesc
#define xmlGetEncodingAlias libtextstyle_xmlGetEncodingAlias
#define xmlGetExternalEntityLoader libtextstyle_xmlGetExternalEntityLoader
#define xmlGetGlobalState libtextstyle_xmlGetGlobalState
#define xmlGetID libtextstyle_xmlGetID
#define xmlGetIntSubset libtextstyle_xmlGetIntSubset
#define xmlGetLastChild libtextstyle_xmlGetLastChild
#define xmlGetLastError libtextstyle_xmlGetLastError
#define xmlGetLineNo libtextstyle_xmlGetLineNo
#define xmlGetNoNsProp libtextstyle_xmlGetNoNsProp
#define xmlGetNodePath libtextstyle_xmlGetNodePath
#define xmlGetNsList libtextstyle_xmlGetNsList
#define xmlGetNsProp libtextstyle_xmlGetNsProp
#define xmlGetParameterEntity libtextstyle_xmlGetParameterEntity
#define xmlGetPredefinedEntity libtextstyle_xmlGetPredefinedEntity
#define xmlGetProp libtextstyle_xmlGetProp
#define xmlGetRefs libtextstyle_xmlGetRefs
#define xmlGetThreadId libtextstyle_xmlGetThreadId
#define xmlGetUTF8Char libtextstyle_xmlGetUTF8Char
#define xmlGetWarningsDefaultValue libtextstyle_xmlGetWarningsDefaultValue
#define xmlHasFeature libtextstyle_xmlHasFeature
#define xmlHasNsProp libtextstyle_xmlHasNsProp
#define xmlHasProp libtextstyle_xmlHasProp
#define xmlHashAddEntry libtextstyle_xmlHashAddEntry
#define xmlHashAddEntry2 libtextstyle_xmlHashAddEntry2
#define xmlHashAddEntry3 libtextstyle_xmlHashAddEntry3
#define xmlHashCopy libtextstyle_xmlHashCopy
#define xmlHashCreate libtextstyle_xmlHashCreate
#define xmlHashCreateDict libtextstyle_xmlHashCreateDict
#define xmlHashDefaultDeallocator libtextstyle_xmlHashDefaultDeallocator
#define xmlHashFree libtextstyle_xmlHashFree
#define xmlHashLookup libtextstyle_xmlHashLookup
#define xmlHashLookup2 libtextstyle_xmlHashLookup2
#define xmlHashLookup3 libtextstyle_xmlHashLookup3
#define xmlHashQLookup libtextstyle_xmlHashQLookup
#define xmlHashQLookup2 libtextstyle_xmlHashQLookup2
#define xmlHashQLookup3 libtextstyle_xmlHashQLookup3
#define xmlHashRemoveEntry libtextstyle_xmlHashRemoveEntry
#define xmlHashRemoveEntry2 libtextstyle_xmlHashRemoveEntry2
#define xmlHashRemoveEntry3 libtextstyle_xmlHashRemoveEntry3
#define xmlHashScan libtextstyle_xmlHashScan
#define xmlHashScan3 libtextstyle_xmlHashScan3
#define xmlHashScanFull libtextstyle_xmlHashScanFull
#define xmlHashScanFull3 libtextstyle_xmlHashScanFull3
#define xmlHashSize libtextstyle_xmlHashSize
#define xmlHashUpdateEntry libtextstyle_xmlHashUpdateEntry
#define xmlHashUpdateEntry2 libtextstyle_xmlHashUpdateEntry2
#define xmlHashUpdateEntry3 libtextstyle_xmlHashUpdateEntry3
#define xmlIndentTreeOutput libtextstyle_xmlIndentTreeOutput
#define xmlInitCharEncodingHandlers libtextstyle_xmlInitCharEncodingHandlers
#define xmlInitGlobals libtextstyle_xmlInitGlobals
#define xmlInitMemory libtextstyle_xmlInitMemory
#define xmlInitNodeInfoSeq libtextstyle_xmlInitNodeInfoSeq
#define xmlInitParser libtextstyle_xmlInitParser
#define xmlInitParserCtxt libtextstyle_xmlInitParserCtxt
#define xmlInitThreads libtextstyle_xmlInitThreads
#define xmlInitializeDict libtextstyle_xmlInitializeDict
#define xmlInitializeGlobalState libtextstyle_xmlInitializeGlobalState
#define xmlInputReadCallbackNop libtextstyle_xmlInputReadCallbackNop
#define xmlIsBaseChar libtextstyle_xmlIsBaseChar
#define xmlIsBaseCharGroup libtextstyle_xmlIsBaseCharGroup
#define xmlIsBlank libtextstyle_xmlIsBlank
#define xmlIsBlankNode libtextstyle_xmlIsBlankNode
#define xmlIsChar libtextstyle_xmlIsChar
#define xmlIsCharGroup libtextstyle_xmlIsCharGroup
#define xmlIsCombining libtextstyle_xmlIsCombining
#define xmlIsCombiningGroup libtextstyle_xmlIsCombiningGroup
#define xmlIsDigit libtextstyle_xmlIsDigit
#define xmlIsDigitGroup libtextstyle_xmlIsDigitGroup
#define xmlIsExtender libtextstyle_xmlIsExtender
#define xmlIsExtenderGroup libtextstyle_xmlIsExtenderGroup
#define xmlIsID libtextstyle_xmlIsID
#define xmlIsIdeographic libtextstyle_xmlIsIdeographic
#define xmlIsIdeographicGroup libtextstyle_xmlIsIdeographicGroup
#define xmlIsLetter libtextstyle_xmlIsLetter
#define xmlIsMainThread libtextstyle_xmlIsMainThread
#define xmlIsMixedElement libtextstyle_xmlIsMixedElement
#define xmlIsPubidChar libtextstyle_xmlIsPubidChar
#define xmlIsPubidChar_tab libtextstyle_xmlIsPubidChar_tab
#define xmlIsRef libtextstyle_xmlIsRef
#define xmlIsXHTML libtextstyle_xmlIsXHTML
#define xmlKeepBlanksDefault libtextstyle_xmlKeepBlanksDefault
#define xmlKeepBlanksDefaultValue libtextstyle_xmlKeepBlanksDefaultValue
#define xmlLastElementChild libtextstyle_xmlLastElementChild
#define xmlLastError libtextstyle_xmlLastError
#define xmlLineNumbersDefault libtextstyle_xmlLineNumbersDefault
#define xmlLineNumbersDefaultValue libtextstyle_xmlLineNumbersDefaultValue
#define xmlLinkGetData libtextstyle_xmlLinkGetData
#define xmlListAppend libtextstyle_xmlListAppend
#define xmlListClear libtextstyle_xmlListClear
#define xmlListCopy libtextstyle_xmlListCopy
#define xmlListCreate libtextstyle_xmlListCreate
#define xmlListDelete libtextstyle_xmlListDelete
#define xmlListDup libtextstyle_xmlListDup
#define xmlListEmpty libtextstyle_xmlListEmpty
#define xmlListEnd libtextstyle_xmlListEnd
#define xmlListFront libtextstyle_xmlListFront
#define xmlListInsert libtextstyle_xmlListInsert
#define xmlListMerge libtextstyle_xmlListMerge
#define xmlListPopBack libtextstyle_xmlListPopBack
#define xmlListPopFront libtextstyle_xmlListPopFront
#define xmlListPushBack libtextstyle_xmlListPushBack
#define xmlListPushFront libtextstyle_xmlListPushFront
#define xmlListRemoveAll libtextstyle_xmlListRemoveAll
#define xmlListRemoveFirst libtextstyle_xmlListRemoveFirst
#define xmlListRemoveLast libtextstyle_xmlListRemoveLast
#define xmlListReverse libtextstyle_xmlListReverse
#define xmlListReverseSearch libtextstyle_xmlListReverseSearch
#define xmlListReverseWalk libtextstyle_xmlListReverseWalk
#define xmlListSearch libtextstyle_xmlListSearch
#define xmlListSize libtextstyle_xmlListSize
#define xmlListSort libtextstyle_xmlListSort
#define xmlListWalk libtextstyle_xmlListWalk
#define xmlLoadExtDtdDefaultValue libtextstyle_xmlLoadExtDtdDefaultValue
#define xmlLoadExternalEntity libtextstyle_xmlLoadExternalEntity
#define xmlLockLibrary libtextstyle_xmlLockLibrary
#define xmlMalloc libtextstyle_xmlMalloc
#define xmlMallocAtomic libtextstyle_xmlMallocAtomic
#define xmlMallocAtomicLoc libtextstyle_xmlMallocAtomicLoc
#define xmlMallocBreakpoint libtextstyle_xmlMallocBreakpoint
#define xmlMallocLoc libtextstyle_xmlMallocLoc
#define xmlMemBlocks libtextstyle_xmlMemBlocks
#define xmlMemDisplay libtextstyle_xmlMemDisplay
#define xmlMemDisplayLast libtextstyle_xmlMemDisplayLast
#define xmlMemFree libtextstyle_xmlMemFree
#define xmlMemGet libtextstyle_xmlMemGet
#define xmlMemMalloc libtextstyle_xmlMemMalloc
#define xmlMemRealloc libtextstyle_xmlMemRealloc
#define xmlMemSetup libtextstyle_xmlMemSetup
#define xmlMemShow libtextstyle_xmlMemShow
#define xmlMemStrdup libtextstyle_xmlMemStrdup
#define xmlMemStrdupLoc libtextstyle_xmlMemStrdupLoc
#define xmlMemUsed libtextstyle_xmlMemUsed
#define xmlMemoryDump libtextstyle_xmlMemoryDump
#define xmlMemoryStrdup libtextstyle_xmlMemoryStrdup
#define xmlMutexLock libtextstyle_xmlMutexLock
#define xmlMutexUnlock libtextstyle_xmlMutexUnlock
#define xmlNewCDataBlock libtextstyle_xmlNewCDataBlock
#define xmlNewCharEncodingHandler libtextstyle_xmlNewCharEncodingHandler
#define xmlNewCharRef libtextstyle_xmlNewCharRef
#define xmlNewChild libtextstyle_xmlNewChild
#define xmlNewComment libtextstyle_xmlNewComment
#define xmlNewDoc libtextstyle_xmlNewDoc
#define xmlNewDocComment libtextstyle_xmlNewDocComment
#define xmlNewDocElementContent libtextstyle_xmlNewDocElementContent
#define xmlNewDocFragment libtextstyle_xmlNewDocFragment
#define xmlNewDocNode libtextstyle_xmlNewDocNode
#define xmlNewDocNodeEatName libtextstyle_xmlNewDocNodeEatName
#define xmlNewDocPI libtextstyle_xmlNewDocPI
#define xmlNewDocProp libtextstyle_xmlNewDocProp
#define xmlNewDocRawNode libtextstyle_xmlNewDocRawNode
#define xmlNewDocText libtextstyle_xmlNewDocText
#define xmlNewDocTextLen libtextstyle_xmlNewDocTextLen
#define xmlNewDtd libtextstyle_xmlNewDtd
#define xmlNewElementContent libtextstyle_xmlNewElementContent
#define xmlNewEntity libtextstyle_xmlNewEntity
#define xmlNewEntityInputStream libtextstyle_xmlNewEntityInputStream
#define xmlNewIOInputStream libtextstyle_xmlNewIOInputStream
#define xmlNewInputFromFile libtextstyle_xmlNewInputFromFile
#define xmlNewInputStream libtextstyle_xmlNewInputStream
#define xmlNewMutex libtextstyle_xmlNewMutex
#define xmlNewNode libtextstyle_xmlNewNode
#define xmlNewNodeEatName libtextstyle_xmlNewNodeEatName
#define xmlNewNs libtextstyle_xmlNewNs
#define xmlNewNsProp libtextstyle_xmlNewNsProp
#define xmlNewNsPropEatName libtextstyle_xmlNewNsPropEatName
#define xmlNewPI libtextstyle_xmlNewPI
#define xmlNewParserCtxt libtextstyle_xmlNewParserCtxt
#define xmlNewProp libtextstyle_xmlNewProp
#define xmlNewRMutex libtextstyle_xmlNewRMutex
#define xmlNewReference libtextstyle_xmlNewReference
#define xmlNewStringInputStream libtextstyle_xmlNewStringInputStream
#define xmlNewText libtextstyle_xmlNewText
#define xmlNewTextChild libtextstyle_xmlNewTextChild
#define xmlNewTextLen libtextstyle_xmlNewTextLen
#define xmlNextChar libtextstyle_xmlNextChar
#define xmlNextElementSibling libtextstyle_xmlNextElementSibling
#define xmlNoNetExternalEntityLoader libtextstyle_xmlNoNetExternalEntityLoader
#define xmlNodeAddContent libtextstyle_xmlNodeAddContent
#define xmlNodeAddContentLen libtextstyle_xmlNodeAddContentLen
#define xmlNodeBufGetContent libtextstyle_xmlNodeBufGetContent
#define xmlNodeGetBase libtextstyle_xmlNodeGetBase
#define xmlNodeGetContent libtextstyle_xmlNodeGetContent
#define xmlNodeGetLang libtextstyle_xmlNodeGetLang
#define xmlNodeGetSpacePreserve libtextstyle_xmlNodeGetSpacePreserve
#define xmlNodeIsText libtextstyle_xmlNodeIsText
#define xmlNodeListGetRawString libtextstyle_xmlNodeListGetRawString
#define xmlNodeListGetString libtextstyle_xmlNodeListGetString
#define xmlNodeSetBase libtextstyle_xmlNodeSetBase
#define xmlNodeSetContent libtextstyle_xmlNodeSetContent
#define xmlNodeSetContentLen libtextstyle_xmlNodeSetContentLen
#define xmlNodeSetLang libtextstyle_xmlNodeSetLang
#define xmlNodeSetName libtextstyle_xmlNodeSetName
#define xmlNodeSetSpacePreserve libtextstyle_xmlNodeSetSpacePreserve
#define xmlNormalizeURIPath libtextstyle_xmlNormalizeURIPath
#define xmlNormalizeWindowsPath libtextstyle_xmlNormalizeWindowsPath
#define xmlOutputBufferCreateFilenameDefault libtextstyle_xmlOutputBufferCreateFilenameDefault
#define xmlOutputBufferCreateFilenameValue libtextstyle_xmlOutputBufferCreateFilenameValue
#define xmlParseAttValue libtextstyle_xmlParseAttValue
#define xmlParseAttributeListDecl libtextstyle_xmlParseAttributeListDecl
#define xmlParseAttributeType libtextstyle_xmlParseAttributeType
#define xmlParseCDSect libtextstyle_xmlParseCDSect
#define xmlParseCharData libtextstyle_xmlParseCharData
#define xmlParseCharEncoding libtextstyle_xmlParseCharEncoding
#define xmlParseCharRef libtextstyle_xmlParseCharRef
#define xmlParseComment libtextstyle_xmlParseComment
#define xmlParseContent libtextstyle_xmlParseContent
#define xmlParseCtxtExternalEntity libtextstyle_xmlParseCtxtExternalEntity
#define xmlParseDefaultDecl libtextstyle_xmlParseDefaultDecl
#define xmlParseDocTypeDecl libtextstyle_xmlParseDocTypeDecl
#define xmlParseDocument libtextstyle_xmlParseDocument
#define xmlParseElement libtextstyle_xmlParseElement
#define xmlParseElementChildrenContentDecl libtextstyle_xmlParseElementChildrenContentDecl
#define xmlParseElementContentDecl libtextstyle_xmlParseElementContentDecl
#define xmlParseElementDecl libtextstyle_xmlParseElementDecl
#define xmlParseElementMixedContentDecl libtextstyle_xmlParseElementMixedContentDecl
#define xmlParseEncName libtextstyle_xmlParseEncName
#define xmlParseEncodingDecl libtextstyle_xmlParseEncodingDecl
#define xmlParseEntityDecl libtextstyle_xmlParseEntityDecl
#define xmlParseEntityRef libtextstyle_xmlParseEntityRef
#define xmlParseEntityValue libtextstyle_xmlParseEntityValue
#define xmlParseEnumeratedType libtextstyle_xmlParseEnumeratedType
#define xmlParseEnumerationType libtextstyle_xmlParseEnumerationType
#define xmlParseExtParsedEnt libtextstyle_xmlParseExtParsedEnt
#define xmlParseExternalID libtextstyle_xmlParseExternalID
#define xmlParseExternalSubset libtextstyle_xmlParseExternalSubset
#define xmlParseInNodeContext libtextstyle_xmlParseInNodeContext
#define xmlParseMarkupDecl libtextstyle_xmlParseMarkupDecl
#define xmlParseMisc libtextstyle_xmlParseMisc
#define xmlParseName libtextstyle_xmlParseName
#define xmlParseNmtoken libtextstyle_xmlParseNmtoken
#define xmlParseNotationDecl libtextstyle_xmlParseNotationDecl
#define xmlParseNotationType libtextstyle_xmlParseNotationType
#define xmlParsePEReference libtextstyle_xmlParsePEReference
#define xmlParsePI libtextstyle_xmlParsePI
#define xmlParsePITarget libtextstyle_xmlParsePITarget
#define xmlParsePubidLiteral libtextstyle_xmlParsePubidLiteral
#define xmlParseReference libtextstyle_xmlParseReference
#define xmlParseSDDecl libtextstyle_xmlParseSDDecl
#define xmlParseSystemLiteral libtextstyle_xmlParseSystemLiteral
#define xmlParseTextDecl libtextstyle_xmlParseTextDecl
#define xmlParseURI libtextstyle_xmlParseURI
#define xmlParseURIRaw libtextstyle_xmlParseURIRaw
#define xmlParseURIReference libtextstyle_xmlParseURIReference
#define xmlParseVersionInfo libtextstyle_xmlParseVersionInfo
#define xmlParseVersionNum libtextstyle_xmlParseVersionNum
#define xmlParseXMLDecl libtextstyle_xmlParseXMLDecl
#define xmlParserAddNodeInfo libtextstyle_xmlParserAddNodeInfo
#define xmlParserDebugEntities libtextstyle_xmlParserDebugEntities
#define xmlParserError libtextstyle_xmlParserError
#define xmlParserFindNodeInfo libtextstyle_xmlParserFindNodeInfo
#define xmlParserFindNodeInfoIndex libtextstyle_xmlParserFindNodeInfoIndex
#define xmlParserGetDirectory libtextstyle_xmlParserGetDirectory
#define xmlParserHandlePEReference libtextstyle_xmlParserHandlePEReference
#define xmlParserInputBufferCreateFd libtextstyle_xmlParserInputBufferCreateFd
#define xmlParserInputBufferCreateFile libtextstyle_xmlParserInputBufferCreateFile
#define xmlParserInputBufferCreateFilename libtextstyle_xmlParserInputBufferCreateFilename
#define xmlParserInputBufferCreateFilenameDefault libtextstyle_xmlParserInputBufferCreateFilenameDefault
#define xmlParserInputBufferCreateFilenameValue libtextstyle_xmlParserInputBufferCreateFilenameValue
#define xmlParserInputBufferCreateIO libtextstyle_xmlParserInputBufferCreateIO
#define xmlParserInputBufferCreateMem libtextstyle_xmlParserInputBufferCreateMem
#define xmlParserInputBufferCreateStatic libtextstyle_xmlParserInputBufferCreateStatic
#define xmlParserInputBufferGrow libtextstyle_xmlParserInputBufferGrow
#define xmlParserInputBufferPush libtextstyle_xmlParserInputBufferPush
#define xmlParserInputBufferRead libtextstyle_xmlParserInputBufferRead
#define xmlParserInputGrow libtextstyle_xmlParserInputGrow
#define xmlParserInputRead libtextstyle_xmlParserInputRead
#define xmlParserInputShrink libtextstyle_xmlParserInputShrink
#define xmlParserMaxDepth libtextstyle_xmlParserMaxDepth
#define xmlParserPrintFileContext libtextstyle_xmlParserPrintFileContext
#define xmlParserPrintFileInfo libtextstyle_xmlParserPrintFileInfo
#define xmlParserValidityError libtextstyle_xmlParserValidityError
#define xmlParserValidityWarning libtextstyle_xmlParserValidityWarning
#define xmlParserVersion libtextstyle_xmlParserVersion
#define xmlParserWarning libtextstyle_xmlParserWarning
#define xmlPathToURI libtextstyle_xmlPathToURI
#define xmlPedanticParserDefault libtextstyle_xmlPedanticParserDefault
#define xmlPedanticParserDefaultValue libtextstyle_xmlPedanticParserDefaultValue
#define xmlPopInput libtextstyle_xmlPopInput
#define xmlPopInputCallbacks libtextstyle_xmlPopInputCallbacks
#define xmlPreviousElementSibling libtextstyle_xmlPreviousElementSibling
#define xmlPrintURI libtextstyle_xmlPrintURI
#define xmlPushInput libtextstyle_xmlPushInput
#define xmlRMutexLock libtextstyle_xmlRMutexLock
#define xmlRMutexUnlock libtextstyle_xmlRMutexUnlock
#define xmlReadDoc libtextstyle_xmlReadDoc
#define xmlReadFd libtextstyle_xmlReadFd
#define xmlReadFile libtextstyle_xmlReadFile
#define xmlReadIO libtextstyle_xmlReadIO
#define xmlReadMemory libtextstyle_xmlReadMemory
#define xmlRealloc libtextstyle_xmlRealloc
#define xmlReallocLoc libtextstyle_xmlReallocLoc
#define xmlReconciliateNs libtextstyle_xmlReconciliateNs
#define xmlRegisterCharEncodingHandler libtextstyle_xmlRegisterCharEncodingHandler
#define xmlRegisterDefaultInputCallbacks libtextstyle_xmlRegisterDefaultInputCallbacks
#define xmlRegisterInputCallbacks libtextstyle_xmlRegisterInputCallbacks
#define xmlRegisterNodeDefault libtextstyle_xmlRegisterNodeDefault
#define xmlRegisterNodeDefaultValue libtextstyle_xmlRegisterNodeDefaultValue
#define xmlRemoveID libtextstyle_xmlRemoveID
#define xmlRemoveProp libtextstyle_xmlRemoveProp
#define xmlRemoveRef libtextstyle_xmlRemoveRef
#define xmlReplaceNode libtextstyle_xmlReplaceNode
#define xmlResetError libtextstyle_xmlResetError
#define xmlResetLastError libtextstyle_xmlResetLastError
#define xmlSAX2AttributeDecl libtextstyle_xmlSAX2AttributeDecl
#define xmlSAX2CDataBlock libtextstyle_xmlSAX2CDataBlock
#define xmlSAX2Characters libtextstyle_xmlSAX2Characters
#define xmlSAX2Comment libtextstyle_xmlSAX2Comment
#define xmlSAX2ElementDecl libtextstyle_xmlSAX2ElementDecl
#define xmlSAX2EndDocument libtextstyle_xmlSAX2EndDocument
#define xmlSAX2EndElementNs libtextstyle_xmlSAX2EndElementNs
#define xmlSAX2EntityDecl libtextstyle_xmlSAX2EntityDecl
#define xmlSAX2ExternalSubset libtextstyle_xmlSAX2ExternalSubset
#define xmlSAX2GetColumnNumber libtextstyle_xmlSAX2GetColumnNumber
#define xmlSAX2GetEntity libtextstyle_xmlSAX2GetEntity
#define xmlSAX2GetLineNumber libtextstyle_xmlSAX2GetLineNumber
#define xmlSAX2GetParameterEntity libtextstyle_xmlSAX2GetParameterEntity
#define xmlSAX2GetPublicId libtextstyle_xmlSAX2GetPublicId
#define xmlSAX2GetSystemId libtextstyle_xmlSAX2GetSystemId
#define xmlSAX2HasExternalSubset libtextstyle_xmlSAX2HasExternalSubset
#define xmlSAX2HasInternalSubset libtextstyle_xmlSAX2HasInternalSubset
#define xmlSAX2IgnorableWhitespace libtextstyle_xmlSAX2IgnorableWhitespace
#define xmlSAX2InitDefaultSAXHandler libtextstyle_xmlSAX2InitDefaultSAXHandler
#define xmlSAX2InternalSubset libtextstyle_xmlSAX2InternalSubset
#define xmlSAX2IsStandalone libtextstyle_xmlSAX2IsStandalone
#define xmlSAX2NotationDecl libtextstyle_xmlSAX2NotationDecl
#define xmlSAX2ProcessingInstruction libtextstyle_xmlSAX2ProcessingInstruction
#define xmlSAX2Reference libtextstyle_xmlSAX2Reference
#define xmlSAX2ResolveEntity libtextstyle_xmlSAX2ResolveEntity
#define xmlSAX2SetDocumentLocator libtextstyle_xmlSAX2SetDocumentLocator
#define xmlSAX2StartDocument libtextstyle_xmlSAX2StartDocument
#define xmlSAX2StartElementNs libtextstyle_xmlSAX2StartElementNs
#define xmlSAX2UnparsedEntityDecl libtextstyle_xmlSAX2UnparsedEntityDecl
#define xmlSAXVersion libtextstyle_xmlSAXVersion
#define xmlSaveNoEmptyTags libtextstyle_xmlSaveNoEmptyTags
#define xmlSaveUri libtextstyle_xmlSaveUri
#define xmlSearchNs libtextstyle_xmlSearchNs
#define xmlSearchNsByHref libtextstyle_xmlSearchNsByHref
#define xmlSetBufferAllocationScheme libtextstyle_xmlSetBufferAllocationScheme
#define xmlSetCompressMode libtextstyle_xmlSetCompressMode
#define xmlSetDocCompressMode libtextstyle_xmlSetDocCompressMode
#define xmlSetExternalEntityLoader libtextstyle_xmlSetExternalEntityLoader
#define xmlSetGenericErrorFunc libtextstyle_xmlSetGenericErrorFunc
#define xmlSetListDoc libtextstyle_xmlSetListDoc
#define xmlSetNs libtextstyle_xmlSetNs
#define xmlSetNsProp libtextstyle_xmlSetNsProp
#define xmlSetProp libtextstyle_xmlSetProp
#define xmlSetStructuredErrorFunc libtextstyle_xmlSetStructuredErrorFunc
#define xmlSetTreeDoc libtextstyle_xmlSetTreeDoc
#define xmlSkipBlankChars libtextstyle_xmlSkipBlankChars
#define xmlSnprintfElementContent libtextstyle_xmlSnprintfElementContent
#define xmlSplitQName libtextstyle_xmlSplitQName
#define xmlSplitQName2 libtextstyle_xmlSplitQName2
#define xmlSplitQName3 libtextstyle_xmlSplitQName3
#define xmlStopParser libtextstyle_xmlStopParser
#define xmlStrEqual libtextstyle_xmlStrEqual
#define xmlStrPrintf libtextstyle_xmlStrPrintf
#define xmlStrQEqual libtextstyle_xmlStrQEqual
#define xmlStrVPrintf libtextstyle_xmlStrVPrintf
#define xmlStrcasecmp libtextstyle_xmlStrcasecmp
#define xmlStrcasestr libtextstyle_xmlStrcasestr
#define xmlStrcat libtextstyle_xmlStrcat
#define xmlStrchr libtextstyle_xmlStrchr
#define xmlStrcmp libtextstyle_xmlStrcmp
#define xmlStrdup libtextstyle_xmlStrdup
#define xmlStringComment libtextstyle_xmlStringComment
#define xmlStringCurrentChar libtextstyle_xmlStringCurrentChar
#define xmlStringDecodeEntities libtextstyle_xmlStringDecodeEntities
#define xmlStringGetNodeList libtextstyle_xmlStringGetNodeList
#define xmlStringLenDecodeEntities libtextstyle_xmlStringLenDecodeEntities
#define xmlStringLenGetNodeList libtextstyle_xmlStringLenGetNodeList
#define xmlStringText libtextstyle_xmlStringText
#define xmlStringTextNoenc libtextstyle_xmlStringTextNoenc
#define xmlStrlen libtextstyle_xmlStrlen
#define xmlStrncasecmp libtextstyle_xmlStrncasecmp
#define xmlStrncat libtextstyle_xmlStrncat
#define xmlStrncatNew libtextstyle_xmlStrncatNew
#define xmlStrncmp libtextstyle_xmlStrncmp
#define xmlStrndup libtextstyle_xmlStrndup
#define xmlStrstr libtextstyle_xmlStrstr
#define xmlStrsub libtextstyle_xmlStrsub
#define xmlStructuredError libtextstyle_xmlStructuredError
#define xmlStructuredErrorContext libtextstyle_xmlStructuredErrorContext
#define xmlSubstituteEntitiesDefault libtextstyle_xmlSubstituteEntitiesDefault
#define xmlSubstituteEntitiesDefaultValue libtextstyle_xmlSubstituteEntitiesDefaultValue
#define xmlSwitchEncoding libtextstyle_xmlSwitchEncoding
#define xmlSwitchInputEncoding libtextstyle_xmlSwitchInputEncoding
#define xmlSwitchToEncoding libtextstyle_xmlSwitchToEncoding
#define xmlTextConcat libtextstyle_xmlTextConcat
#define xmlTextMerge libtextstyle_xmlTextMerge
#define xmlThrDefBufferAllocScheme libtextstyle_xmlThrDefBufferAllocScheme
#define xmlThrDefDefaultBufferSize libtextstyle_xmlThrDefDefaultBufferSize
#define xmlThrDefDeregisterNodeDefault libtextstyle_xmlThrDefDeregisterNodeDefault
#define xmlThrDefDoValidityCheckingDefaultValue libtextstyle_xmlThrDefDoValidityCheckingDefaultValue
#define xmlThrDefGetWarningsDefaultValue libtextstyle_xmlThrDefGetWarningsDefaultValue
#define xmlThrDefIndentTreeOutput libtextstyle_xmlThrDefIndentTreeOutput
#define xmlThrDefKeepBlanksDefaultValue libtextstyle_xmlThrDefKeepBlanksDefaultValue
#define xmlThrDefLineNumbersDefaultValue libtextstyle_xmlThrDefLineNumbersDefaultValue
#define xmlThrDefLoadExtDtdDefaultValue libtextstyle_xmlThrDefLoadExtDtdDefaultValue
#define xmlThrDefOutputBufferCreateFilenameDefault libtextstyle_xmlThrDefOutputBufferCreateFilenameDefault
#define xmlThrDefParserDebugEntities libtextstyle_xmlThrDefParserDebugEntities
#define xmlThrDefParserInputBufferCreateFilenameDefault libtextstyle_xmlThrDefParserInputBufferCreateFilenameDefault
#define xmlThrDefPedanticParserDefaultValue libtextstyle_xmlThrDefPedanticParserDefaultValue
#define xmlThrDefRegisterNodeDefault libtextstyle_xmlThrDefRegisterNodeDefault
#define xmlThrDefSaveNoEmptyTags libtextstyle_xmlThrDefSaveNoEmptyTags
#define xmlThrDefSetGenericErrorFunc libtextstyle_xmlThrDefSetGenericErrorFunc
#define xmlThrDefSetStructuredErrorFunc libtextstyle_xmlThrDefSetStructuredErrorFunc
#define xmlThrDefSubstituteEntitiesDefaultValue libtextstyle_xmlThrDefSubstituteEntitiesDefaultValue
#define xmlThrDefTreeIndentString libtextstyle_xmlThrDefTreeIndentString
#define xmlTreeIndentString libtextstyle_xmlTreeIndentString
#define xmlURIEscape libtextstyle_xmlURIEscape
#define xmlURIEscapeStr libtextstyle_xmlURIEscapeStr
#define xmlURIUnescapeString libtextstyle_xmlURIUnescapeString
#define xmlUTF8Charcmp libtextstyle_xmlUTF8Charcmp
#define xmlUTF8Size libtextstyle_xmlUTF8Size
#define xmlUTF8Strlen libtextstyle_xmlUTF8Strlen
#define xmlUTF8Strloc libtextstyle_xmlUTF8Strloc
#define xmlUTF8Strndup libtextstyle_xmlUTF8Strndup
#define xmlUTF8Strpos libtextstyle_xmlUTF8Strpos
#define xmlUTF8Strsize libtextstyle_xmlUTF8Strsize
#define xmlUTF8Strsub libtextstyle_xmlUTF8Strsub
#define xmlUnlinkNode libtextstyle_xmlUnlinkNode
#define xmlUnlockLibrary libtextstyle_xmlUnlockLibrary
#define xmlUnsetNsProp libtextstyle_xmlUnsetNsProp
#define xmlUnsetProp libtextstyle_xmlUnsetProp
#define xmlValidateNCName libtextstyle_xmlValidateNCName
#define xmlValidateNMToken libtextstyle_xmlValidateNMToken
#define xmlValidateName libtextstyle_xmlValidateName
#define xmlValidateQName libtextstyle_xmlValidateQName
#define xnmalloc libtextstyle_xnmalloc
#define xrealloc libtextstyle_xrealloc
#define xstrdup libtextstyle_xstrdup
#define xvasprintf libtextstyle_xvasprintf
#define xzalloc libtextstyle_xzalloc
