EXPORTS
catalog_reader_alloc
catalog_reader_free
catalog_reader_parse
catenate_msgdomain_list
check_message_list
check_msgid_msgstr_format_i
check_plural_eval
cleanup_temp_dir
compare_po_locale_charsets
convert_string_directly
create_temp_dir
default_add_message
default_catalog_reader_alloc
default_constructor
default_comment_dot
default_comment
default_comment_filepos
default_comment_special
default_destructor
default_directive_domain
default_directive_message
default_parse_brief
default_parse_debrief
default_set_domain
desktop_add_default_keywords
desktop_add_keyword
desktop_escape_string
desktop_parse
desktop_reader_alloc
desktop_reader_free
desktop_unescape_string
dir_list_append
dir_list_nth
dir_list_restore
dir_list_save_reset
extract_plural_expression
fopen_temp
fuzzy_search_goal_function
fwriteerror_temp
get_search_path
get_python_format_unnamed_arg_count
get_sysdep_c_format_directives
handle_filepos_comment_option
iconv_message_list
iconv_msgdomain_list
is_ascii_message_list
is_ascii_msgdomain_list
is_ascii_string
is_message_list_iconvable
its_merge_context_alloc
its_merge_context_free
its_merge_context_merge
its_merge_context_write
its_rule_list_add_from_file
its_rule_list_add_from_string
its_rule_list_alloc
its_rule_list_extract
its_rule_list_free
locating_rule_list_add_from_directory
locating_rule_list_alloc
locating_rule_list_free
locating_rule_list_locate
message_alloc
message_comment_append
message_comment_dot_append
message_comment_filepos
message_copy
message_list_alloc
message_list_append
message_list_delete_header_field
message_list_free
message_list_list_alloc
message_list_list_append
message_list_list_append_list
message_list_list_free
message_list_list_search
message_list_prepend
message_list_remove_if_not
message_list_search
message_list_search_fuzzy
message_page_width_ignore
message_page_width_set
message_print_style_comment
message_print_style_escape
message_print_style_filepos
message_print_style_indent
message_print_style_uniforum
msgdomain_list_alloc
msgdomain_list_english
msgdomain_list_equal
msgdomain_list_free
msgdomain_list_print
msgdomain_list_set_header_field
msgdomain_list_sort_by_filepos
msgdomain_list_sort_by_msgid
msgdomain_list_sublist
open_catalog_file
possible_format_p
po_charset_canonicalize
po_charset_character_iterator
po_gram_error_at_line
po_lex_pass_obsolete_entries
po_parse_comment_special
po_strftime
read_catalog_file
read_catalog_stream
read_names_from_file
register_temp_file
register_temp_subdir
string_list_alloc
string_list_append
string_list_append_unique
string_list_destroy
string_list_free
string_list_init
string_list_join
string_list_member
string_list_remove
syntax_check_message_list
unregister_temp_file
unregister_temp_subdir