# flake8: noqa

from gvsbuild.projects.adwaita_icon_theme import AdwaitaIconTheme
from gvsbuild.projects.atk import Atk
from gvsbuild.projects.boringssl import BoringSSL
from gvsbuild.projects.cairo import Cairo
from gvsbuild.projects.check_libs import CheckLibs
from gvsbuild.projects.clutter import Clutter
from gvsbuild.projects.cogl import Cogl
from gvsbuild.projects.cyrus_sasl import CyrusSasl
from gvsbuild.projects.dcv_color_primitives import DcvColorPrimitives
from gvsbuild.projects.dev_shell import DevShell
from gvsbuild.projects.emeus import Emeus
from gvsbuild.projects.enchant import Enchant
from gvsbuild.projects.ffmpeg import Ffmpeg
from gvsbuild.projects.fontconfig import Fontconfig
from gvsbuild.projects.freerdp import FreeRDP
from gvsbuild.projects.freetype import Freetype
from gvsbuild.projects.fribidi import Fribidi
from gvsbuild.projects.gdk_pixbuf import GdkPixbuf
from gvsbuild.projects.gettext import Gettext
from gvsbuild.projects.glib import GLib, GLibNetworking, GLibPyWrapper
from gvsbuild.projects.gobject_introspection import GObjectIntrospection
from gvsbuild.projects.graphene import Graphene
from gvsbuild.projects.gsettings_desktop_schemas import GSettingsDesktopSchemas
from gvsbuild.projects.gstreamer import (
    GstPluginsBad,
    GstPluginsBase,
    GstPluginsGood,
    GstPython,
    GStreamer,
    Orc,
)
from gvsbuild.projects.gtk import Gtk2, Gtk3, Gtk4
from gvsbuild.projects.gtksourceview import GtkSourceView4, GtkSourceView5
from gvsbuild.projects.harfbuzz import Harfbuzz
from gvsbuild.projects.hicolor_icon_theme import HicolorIconTheme
from gvsbuild.projects.icu import Icu
from gvsbuild.projects.json_glib import JsonGLib
from gvsbuild.projects.jsonc import Jsonc
from gvsbuild.projects.leveldb import LevelDB
from gvsbuild.projects.lgi import Lgi
from gvsbuild.projects.libadwaita import Libadwaita
from gvsbuild.projects.libarchive import Libarchive
from gvsbuild.projects.libcroco import Libcroco
from gvsbuild.projects.libcurl import Libcurl
from gvsbuild.projects.libepoxy import Libepoxy
from gvsbuild.projects.libffi import Libffi
from gvsbuild.projects.libgxps import Libgxps
from gvsbuild.projects.libjpeg_turbo import LibjpegTurbo
from gvsbuild.projects.libmicrohttpd import Libmicrohttpd
from gvsbuild.projects.libpng import Libpng
from gvsbuild.projects.libpsl import Libpsl
from gvsbuild.projects.librsvg import Librsvg
from gvsbuild.projects.libsoup import Libsoup2, Libsoup3
from gvsbuild.projects.libssh import Libssh, Libssh2
from gvsbuild.projects.libtiff import Libtiff4
from gvsbuild.projects.libuv import Libuv
from gvsbuild.projects.libvpx import Libvpx
from gvsbuild.projects.libxml2 import Libxml2
from gvsbuild.projects.libyuv import Libyuv
from gvsbuild.projects.libzip import Libzip
from gvsbuild.projects.lmdb import Lmdb
from gvsbuild.projects.luajit import Luajit
from gvsbuild.projects.lz4 import Lz4
from gvsbuild.projects.mit_kerberos import Kerberos
from gvsbuild.projects.nghttp2 import Nghttp2
from gvsbuild.projects.openh264 import OpenH264
from gvsbuild.projects.openssl import OpenSSL
from gvsbuild.projects.opus import Opus
from gvsbuild.projects.pango import Pango
from gvsbuild.projects.pixman import Pixman
from gvsbuild.projects.pkgconf import PkgConf
from gvsbuild.projects.portaudio import Portaudio
from gvsbuild.projects.protobuf import Protobuf, ProtobufC
from gvsbuild.projects.pycairo import Pycairo
from gvsbuild.projects.pygobject import PyGObject
from gvsbuild.projects.sqlite import SQLite
from gvsbuild.projects.win_iconv import WinIconv
from gvsbuild.projects.wing import Wing
from gvsbuild.projects.x264 import X264
from gvsbuild.projects.zlib import Zlib
