LIBRARY "leveldb.dll"

EXPORTS 

leveldb_open

leveldb_close

leveldb_put

leveldb_delete

leveldb_write

leveldb_get

leveldb_create_iterator

leveldb_create_snapshot

leveldb_release_snapshot

leveldb_property_value

leveldb_approximate_sizes

leveldb_destroy_db

leveldb_repair_db

leveldb_iter_destroy

leveldb_iter_valid

leveldb_iter_seek_to_first

leveldb_iter_seek_to_last

leveldb_iter_seek

leveldb_iter_next

leveldb_iter_prev

leveldb_iter_key

leveldb_iter_value

leveldb_iter_get_error

leveldb_writebatch_create

leveldb_writebatch_destroy

leveldb_writebatch_clear

leveldb_writebatch_put

leveldb_writebatch_delete

leveldb_writebatch_iterate

leveldb_options_create

leveldb_options_destroy

leveldb_options_set_comparator

leveldb_options_set_create_if_missing

leveldb_options_set_error_if_exists

leveldb_options_set_paranoid_checks

leveldb_options_set_env

leveldb_options_set_info_log

leveldb_options_set_write_buffer_size

leveldb_options_set_max_open_files

leveldb_options_set_cache

leveldb_options_set_block_size

leveldb_options_set_block_restart_interval

leveldb_options_set_compression

leveldb_comparator_create

leveldb_comparator_destroy

leveldb_readoptions_create

leveldb_readoptions_destroy

leveldb_readoptions_set_verify_checksums

leveldb_readoptions_set_fill_cache

leveldb_readoptions_set_snapshot

leveldb_writeoptions_create

leveldb_writeoptions_destroy

leveldb_writeoptions_set_sync

leveldb_cache_create_lru

leveldb_cache_destroy

leveldb_create_default_env

leveldb_env_destroy
