/* DO NOT EDIT! GENERATED AUTOMATICALLY! */
#ifndef GTPO_CONFIG_H
#define GTPO_CONFIG_H

#include "../config.h"
#define DEFAULT_TEXT_DOMAIN "gettext-tools"
#undef DLL_VARIABLE
#define DLL_VARIABLE

#endif /* GTPO_CONFIG_H */
#define _gl_convert_FILETIME_to_POSIX libgettextpo__gl_convert_FILETIME_to_POSIX
#define _gl_fstat_by_handle libgettextpo__gl_fstat_by_handle
#define _gl_nothrow_get_osfhandle libgettextpo__gl_nothrow_get_osfhandle
#define _gl_raise_SIGPIPE libgettextpo__gl_raise_SIGPIPE
#define _obstack_allocated_p libgettextpo__obstack_allocated_p
#define _obstack_begin libgettextpo__obstack_begin
#define _obstack_begin_1 libgettextpo__obstack_begin_1
#define _obstack_free libgettextpo__obstack_free
#define _obstack_memory_used libgettextpo__obstack_memory_used
#define _obstack_newchunk libgettextpo__obstack_newchunk
#define allow_duplicates libgettextpo_allow_duplicates
#define asnprintf libgettextpo_asnprintf
#define asprintf libgettextpo_asprintf
#define base_len libgettextpo_base_len
#define c_strcasecmp libgettextpo_c_strcasecmp
#define c_strncasecmp libgettextpo_c_strncasecmp
#define c_strstr libgettextpo_c_strstr
#define catalog_reader_alloc libgettextpo_catalog_reader_alloc
#define catalog_reader_free libgettextpo_catalog_reader_free
#define catalog_reader_parse libgettextpo_catalog_reader_parse
#define check_message libgettextpo_check_message
#define check_message_list libgettextpo_check_message_list
#define check_msgid_msgstr_format libgettextpo_check_msgid_msgstr_format
#define check_msgid_msgstr_format_i libgettextpo_check_msgid_msgstr_format_i
#define check_plural_eval libgettextpo_check_plural_eval
#define concatenated_filename libgettextpo_concatenated_filename
#define default_add_message libgettextpo_default_add_message
#define default_catalog_reader_alloc libgettextpo_default_catalog_reader_alloc
#define default_comment libgettextpo_default_comment
#define default_comment_dot libgettextpo_default_comment_dot
#define default_comment_filepos libgettextpo_default_comment_filepos
#define default_comment_special libgettextpo_default_comment_special
#define default_constructor libgettextpo_default_constructor
#define default_destructor libgettextpo_default_destructor
#define default_directive_domain libgettextpo_default_directive_domain
#define default_directive_message libgettextpo_default_directive_message
#define default_parse_brief libgettextpo_default_parse_brief
#define default_parse_debrief libgettextpo_default_parse_debrief
#define default_set_domain libgettextpo_default_set_domain
#define dir_list_append libgettextpo_dir_list_append
#define dir_list_nth libgettextpo_dir_list_nth
#define dir_list_restore libgettextpo_dir_list_restore
#define dir_list_save_reset libgettextpo_dir_list_save_reset
#define dup_cloexec libgettextpo_dup_cloexec
#define error libgettextpo_error
#define error_at_line libgettextpo_error_at_line
#define error_with_progname libgettextpo_error_with_progname
#define execute_all_close_hooks libgettextpo_execute_all_close_hooks
#define execute_all_ioctl_hooks libgettextpo_execute_all_ioctl_hooks
#define execute_close_hooks libgettextpo_execute_close_hooks
#define execute_ioctl_hooks libgettextpo_execute_ioctl_hooks
#define exit_failure libgettextpo_exit_failure
#define extract_plural_expression libgettextpo_extract_plural_expression
#define fcntl libgettextpo_fcntl
#define format_language libgettextpo_format_language
#define format_language_pretty libgettextpo_format_language_pretty
#define formatstring_awk libgettextpo_formatstring_awk
#define formatstring_boost libgettextpo_formatstring_boost
#define formatstring_c libgettextpo_formatstring_c
#define formatstring_csharp libgettextpo_formatstring_csharp
#define formatstring_elisp libgettextpo_formatstring_elisp
#define formatstring_gcc_internal libgettextpo_formatstring_gcc_internal
#define formatstring_gfc_internal libgettextpo_formatstring_gfc_internal
#define formatstring_java libgettextpo_formatstring_java
#define formatstring_java_printf libgettextpo_formatstring_java_printf
#define formatstring_javascript libgettextpo_formatstring_javascript
#define formatstring_kde libgettextpo_formatstring_kde
#define formatstring_kde_kuit libgettextpo_formatstring_kde_kuit
#define formatstring_librep libgettextpo_formatstring_librep
#define formatstring_lisp libgettextpo_formatstring_lisp
#define formatstring_lua libgettextpo_formatstring_lua
#define formatstring_objc libgettextpo_formatstring_objc
#define formatstring_parsers libgettextpo_formatstring_parsers
#define formatstring_pascal libgettextpo_formatstring_pascal
#define formatstring_perl libgettextpo_formatstring_perl
#define formatstring_perl_brace libgettextpo_formatstring_perl_brace
#define formatstring_php libgettextpo_formatstring_php
#define formatstring_python libgettextpo_formatstring_python
#define formatstring_python_brace libgettextpo_formatstring_python_brace
#define formatstring_qt libgettextpo_formatstring_qt
#define formatstring_qt_plural libgettextpo_formatstring_qt_plural
#define formatstring_ruby libgettextpo_formatstring_ruby
#define formatstring_scheme libgettextpo_formatstring_scheme
#define formatstring_sh libgettextpo_formatstring_sh
#define formatstring_smalltalk libgettextpo_formatstring_smalltalk
#define formatstring_tcl libgettextpo_formatstring_tcl
#define formatstring_ycp libgettextpo_formatstring_ycp
#define free_plural_expression libgettextpo_free_plural_expression
#define freea libgettextpo_freea
#define fstrcmp_bounded libgettextpo_fstrcmp_bounded
#define fstrcmp_free_resources libgettextpo_fstrcmp_free_resources
#define fsync libgettextpo_fsync
#define fuzzy_search_goal_function libgettextpo_fuzzy_search_goal_function
#define fwriteerror libgettextpo_fwriteerror
#define fwriteerror_no_ebadf libgettextpo_fwriteerror_no_ebadf
#define gcd libgettextpo_gcd
#define germanic_plural libgettextpo_germanic_plural
#define get_python_format_unnamed_arg_count libgettextpo_get_python_format_unnamed_arg_count
#define get_sysdep_c_format_directives libgettextpo_get_sysdep_c_format_directives
#define getdelim libgettextpo_getdelim
#define getdtablesize libgettextpo_getdtablesize
#define getprogname libgettextpo_getprogname
#define gl_linked_list_implementation libgettextpo_gl_linked_list_implementation
#define gl_msvc_inval_ensure_handler libgettextpo_gl_msvc_inval_ensure_handler
#define glwthread_mutex_destroy libgettextpo_glwthread_mutex_destroy
#define glwthread_mutex_init libgettextpo_glwthread_mutex_init
#define glwthread_mutex_lock libgettextpo_glwthread_mutex_lock
#define glwthread_mutex_trylock libgettextpo_glwthread_mutex_trylock
#define glwthread_mutex_unlock libgettextpo_glwthread_mutex_unlock
#define glwthread_once libgettextpo_glwthread_once
#define glwthread_recmutex_destroy libgettextpo_glwthread_recmutex_destroy
#define glwthread_recmutex_init libgettextpo_glwthread_recmutex_init
#define glwthread_recmutex_lock libgettextpo_glwthread_recmutex_lock
#define glwthread_recmutex_trylock libgettextpo_glwthread_recmutex_trylock
#define glwthread_recmutex_unlock libgettextpo_glwthread_recmutex_unlock
#define glwthread_rwlock_destroy libgettextpo_glwthread_rwlock_destroy
#define glwthread_rwlock_init libgettextpo_glwthread_rwlock_init
#define glwthread_rwlock_rdlock libgettextpo_glwthread_rwlock_rdlock
#define glwthread_rwlock_tryrdlock libgettextpo_glwthread_rwlock_tryrdlock
#define glwthread_rwlock_trywrlock libgettextpo_glwthread_rwlock_trywrlock
#define glwthread_rwlock_unlock libgettextpo_glwthread_rwlock_unlock
#define glwthread_rwlock_wrlock libgettextpo_glwthread_rwlock_wrlock
#define glwthread_tls_get libgettextpo_glwthread_tls_get
#define glwthread_tls_key_create libgettextpo_glwthread_tls_key_create
#define glwthread_tls_key_delete libgettextpo_glwthread_tls_key_delete
#define glwthread_tls_process_destructors libgettextpo_glwthread_tls_process_destructors
#define glwthread_tls_set libgettextpo_glwthread_tls_set
#define gnu_mbswidth libgettextpo_gnu_mbswidth
#define gram_max_allowed_errors libgettextpo_gram_max_allowed_errors
#define gram_pos libgettextpo_gram_pos
#define gram_pos_column libgettextpo_gram_pos_column
#define handle_filepos_comment_option libgettextpo_handle_filepos_comment_option
#define hard_locale libgettextpo_hard_locale
#define hash_destroy libgettextpo_hash_destroy
#define hash_find_entry libgettextpo_hash_find_entry
#define hash_init libgettextpo_hash_init
#define hash_insert_entry libgettextpo_hash_insert_entry
#define hash_iterate libgettextpo_hash_iterate
#define hash_iterate_modify libgettextpo_hash_iterate_modify
#define hash_set_value libgettextpo_hash_set_value
#define iconveh_close libgettextpo_iconveh_close
#define iconveh_open libgettextpo_iconveh_open
#define input_format_po libgettextpo_input_format_po
#define install_sigfpe_handler libgettextpo_install_sigfpe_handler
#define is_ascii_message libgettextpo_is_ascii_message
#define is_ascii_message_list libgettextpo_is_ascii_message_list
#define is_ascii_msgdomain_list libgettextpo_is_ascii_msgdomain_list
#define is_ascii_string libgettextpo_is_ascii_string
#define is_ascii_string_list libgettextpo_is_ascii_string_list
#define last_component libgettextpo_last_component
#define lex_end libgettextpo_lex_end
#define lex_start libgettextpo_lex_start
#define locale_charset libgettextpo_locale_charset
#define make_format_description_string libgettextpo_make_format_description_string
#define make_range_description_string libgettextpo_make_range_description_string
#define markup_parse_context_end_parse libgettextpo_markup_parse_context_end_parse
#define markup_parse_context_free libgettextpo_markup_parse_context_free
#define markup_parse_context_get_error libgettextpo_markup_parse_context_get_error
#define markup_parse_context_new libgettextpo_markup_parse_context_new
#define markup_parse_context_parse libgettextpo_markup_parse_context_parse
#define maybe_print_progname libgettextpo_maybe_print_progname
#define mbsnwidth libgettextpo_mbsnwidth
#define mem_cd_iconv libgettextpo_mem_cd_iconv
#define mem_cd_iconveh libgettextpo_mem_cd_iconveh
#define mem_iconveh libgettextpo_mem_iconveh
#define mem_iconveha libgettextpo_mem_iconveha
#define message_alloc libgettextpo_message_alloc
#define message_comment_append libgettextpo_message_comment_append
#define message_comment_dot_append libgettextpo_message_comment_dot_append
#define message_comment_filepos libgettextpo_message_comment_filepos
#define message_copy libgettextpo_message_copy
#define message_free libgettextpo_message_free
#define message_list_alloc libgettextpo_message_list_alloc
#define message_list_append libgettextpo_message_list_append
#define message_list_copy libgettextpo_message_list_copy
#define message_list_free libgettextpo_message_list_free
#define message_list_insert_at libgettextpo_message_list_insert_at
#define message_list_list_alloc libgettextpo_message_list_list_alloc
#define message_list_list_append libgettextpo_message_list_list_append
#define message_list_list_append_list libgettextpo_message_list_list_append_list
#define message_list_list_free libgettextpo_message_list_list_free
#define message_list_list_search libgettextpo_message_list_list_search
#define message_list_msgids_changed libgettextpo_message_list_msgids_changed
#define message_list_prepend libgettextpo_message_list_prepend
#define message_list_remove_if_not libgettextpo_message_list_remove_if_not
#define message_list_search libgettextpo_message_list_search
#define message_list_search_fuzzy libgettextpo_message_list_search_fuzzy
#define message_page_width_ignore libgettextpo_message_page_width_ignore
#define message_page_width_set libgettextpo_message_page_width_set
#define message_print_comment libgettextpo_message_print_comment
#define message_print_comment_dot libgettextpo_message_print_comment_dot
#define message_print_comment_filepos libgettextpo_message_print_comment_filepos
#define message_print_comment_flags libgettextpo_message_print_comment_flags
#define message_print_style_comment libgettextpo_message_print_style_comment
#define message_print_style_escape libgettextpo_message_print_style_escape
#define message_print_style_filepos libgettextpo_message_print_style_filepos
#define message_print_style_indent libgettextpo_message_print_style_indent
#define message_print_style_uniforum libgettextpo_message_print_style_uniforum
#define mmalloca libgettextpo_mmalloca
#define msgdomain_alloc libgettextpo_msgdomain_alloc
#define msgdomain_free libgettextpo_msgdomain_free
#define msgdomain_list_alloc libgettextpo_msgdomain_list_alloc
#define msgdomain_list_append libgettextpo_msgdomain_list_append
#define msgdomain_list_copy libgettextpo_msgdomain_list_copy
#define msgdomain_list_free libgettextpo_msgdomain_list_free
#define msgdomain_list_print libgettextpo_msgdomain_list_print
#define msgdomain_list_sort_by_filepos libgettextpo_msgdomain_list_sort_by_filepos
#define msgdomain_list_sort_by_msgid libgettextpo_msgdomain_list_sort_by_msgid
#define msgdomain_list_sublist libgettextpo_msgdomain_list_sublist
#define multiline_error libgettextpo_multiline_error
#define multiline_warning libgettextpo_multiline_warning
#define next_prime libgettextpo_next_prime
#define obstack_alloc_failed_handler libgettextpo_obstack_alloc_failed_handler
#define open_catalog_file libgettextpo_open_catalog_file
#define output_format_po libgettextpo_output_format_po
#define parse_plural_expression libgettextpo_parse_plural_expression
#define pass_obsolete_entries libgettextpo_pass_obsolete_entries
#define plural_eval libgettextpo_plural_eval
#define plural_table libgettextpo_plural_table
#define plural_table_size libgettextpo_plural_table_size
#define po_callback_comment libgettextpo_po_callback_comment
#define po_callback_comment_dispatcher libgettextpo_po_callback_comment_dispatcher
#define po_callback_comment_dot libgettextpo_po_callback_comment_dot
#define po_callback_comment_filepos libgettextpo_po_callback_comment_filepos
#define po_callback_comment_special libgettextpo_po_callback_comment_special
#define po_callback_domain libgettextpo_po_callback_domain
#define po_callback_message libgettextpo_po_callback_message
#define po_charset_ascii libgettextpo_po_charset_ascii
#define po_charset_ascii_compatible libgettextpo_po_charset_ascii_compatible
#define po_charset_canonicalize libgettextpo_po_charset_canonicalize
#define po_charset_character_iterator libgettextpo_po_charset_character_iterator
#define po_charset_utf8 libgettextpo_po_charset_utf8
#define po_error libgettextpo_po_error
#define po_error_at_line libgettextpo_po_error_at_line
#define po_gram_char libgettextpo_po_gram_char
#define po_gram_error libgettextpo_po_gram_error
#define po_gram_error_at_line libgettextpo_po_gram_error_at_line
#define po_gram_lex libgettextpo_po_gram_lex
#define po_gram_lval libgettextpo_po_gram_lval
#define po_gram_nerrs libgettextpo_po_gram_nerrs
#define po_gram_parse libgettextpo_po_gram_parse
#define po_is_charset_weird libgettextpo_po_is_charset_weird
#define po_is_charset_weird_cjk libgettextpo_po_is_charset_weird_cjk
#define po_lex_charset libgettextpo_po_lex_charset
#define po_lex_charset_close libgettextpo_po_lex_charset_close
#define po_lex_charset_init libgettextpo_po_lex_charset_init
#define po_lex_charset_set libgettextpo_po_lex_charset_set
#define po_lex_iconv libgettextpo_po_lex_iconv
#define po_lex_pass_comments libgettextpo_po_lex_pass_comments
#define po_lex_pass_obsolete_entries libgettextpo_po_lex_pass_obsolete_entries
#define po_lex_weird_cjk libgettextpo_po_lex_weird_cjk
#define po_multiline_error libgettextpo_po_multiline_error
#define po_multiline_warning libgettextpo_po_multiline_warning
#define po_parse_comment_special libgettextpo_po_parse_comment_special
#define po_xerror libgettextpo_po_xerror
#define po_xerror2 libgettextpo_po_xerror2
#define possible_format_p libgettextpo_possible_format_p
#define printf_fetchargs libgettextpo_printf_fetchargs
#define printf_parse libgettextpo_printf_parse
#define rawmemchr libgettextpo_rawmemchr
#define read_catalog_file libgettextpo_read_catalog_file
#define read_catalog_stream libgettextpo_read_catalog_stream
#define register_fd_hook libgettextpo_register_fd_hook
#define rpl_close libgettextpo_rpl_close
#define rpl_dup2 libgettextpo_rpl_dup2
#define rpl_error_message_count libgettextpo_rpl_error_message_count
#define rpl_error_one_per_line libgettextpo_rpl_error_one_per_line
#define rpl_error_print_progname libgettextpo_rpl_error_print_progname
#define rpl_fdopen libgettextpo_rpl_fdopen
#define rpl_fopen libgettextpo_rpl_fopen
#define rpl_fprintf libgettextpo_rpl_fprintf
#define rpl_fputc libgettextpo_rpl_fputc
#define rpl_fputs libgettextpo_rpl_fputs
#define rpl_fstat libgettextpo_rpl_fstat
#define rpl_fwrite libgettextpo_rpl_fwrite
#define rpl_getline libgettextpo_rpl_getline
#define rpl_malloc libgettextpo_rpl_malloc
#define rpl_mbrtowc libgettextpo_rpl_mbrtowc
#define rpl_mbsinit libgettextpo_rpl_mbsinit
#define rpl_open libgettextpo_rpl_open
#define rpl_printf libgettextpo_rpl_printf
#define rpl_putchar libgettextpo_rpl_putchar
#define rpl_puts libgettextpo_rpl_puts
#define rpl_raise libgettextpo_rpl_raise
#define rpl_realloc libgettextpo_rpl_realloc
#define rpl_signal libgettextpo_rpl_signal
#define rpl_stat libgettextpo_rpl_stat
#define rpl_strerror libgettextpo_rpl_strerror
#define rpl_strstr libgettextpo_rpl_strstr
#define rpl_vfprintf libgettextpo_rpl_vfprintf
#define rpl_vprintf libgettextpo_rpl_vprintf
#define sentence_end libgettextpo_sentence_end
#define sentence_end_required_spaces libgettextpo_sentence_end_required_spaces
#define set_cloexec_flag libgettextpo_set_cloexec_flag
#define setlocale_null libgettextpo_setlocale_null
#define setlocale_null_r libgettextpo_setlocale_null_r
#define sigaddset libgettextpo_sigaddset
#define sigdelset libgettextpo_sigdelset
#define sigemptyset libgettextpo_sigemptyset
#define sigfillset libgettextpo_sigfillset
#define sigfpe_exit libgettextpo_sigfpe_exit
#define sigismember libgettextpo_sigismember
#define significant_format_p libgettextpo_significant_format_p
#define sigpending libgettextpo_sigpending
#define sigprocmask libgettextpo_sigprocmask
#define stpcpy libgettextpo_stpcpy
#define stpncpy libgettextpo_stpncpy
#define str_cd_iconv libgettextpo_str_cd_iconv
#define str_cd_iconveh libgettextpo_str_cd_iconveh
#define str_iconv libgettextpo_str_iconv
#define str_iconveh libgettextpo_str_iconveh
#define str_iconveha libgettextpo_str_iconveha
#define strchrnul libgettextpo_strchrnul
#define strerror_override libgettextpo_strerror_override
#define string_list_alloc libgettextpo_string_list_alloc
#define string_list_append libgettextpo_string_list_append
#define string_list_append_unique libgettextpo_string_list_append_unique
#define string_list_concat libgettextpo_string_list_concat
#define string_list_concat_destroy libgettextpo_string_list_concat_destroy
#define string_list_destroy libgettextpo_string_list_destroy
#define string_list_free libgettextpo_string_list_free
#define string_list_init libgettextpo_string_list_init
#define string_list_join libgettextpo_string_list_join
#define string_list_member libgettextpo_string_list_member
#define string_list_remove libgettextpo_string_list_remove
#define syntax_check_message_list libgettextpo_syntax_check_message_list
#define syntax_check_name libgettextpo_syntax_check_name
#define textmode_xerror libgettextpo_textmode_xerror
#define textmode_xerror2 libgettextpo_textmode_xerror2
#define u16_mbtouc_aux libgettextpo_u16_mbtouc_aux
#define u8_check libgettextpo_u8_check
#define u8_conv_from_encoding libgettextpo_u8_conv_from_encoding
#define u8_mblen libgettextpo_u8_mblen
#define u8_mbtouc_aux libgettextpo_u8_mbtouc_aux
#define u8_mbtouc_unsafe_aux libgettextpo_u8_mbtouc_unsafe_aux
#define u8_mbtoucr libgettextpo_u8_mbtoucr
#define u8_next libgettextpo_u8_next
#define u8_possible_linebreaks libgettextpo_u8_possible_linebreaks
#define u8_prev libgettextpo_u8_prev
#define u8_strmbtouc libgettextpo_u8_strmbtouc
#define u8_uctomb_aux libgettextpo_u8_uctomb_aux
#define u8_width_linebreaks libgettextpo_u8_width_linebreaks
#define uc_is_alpha libgettextpo_uc_is_alpha
#define uc_is_space libgettextpo_uc_is_space
#define uc_width libgettextpo_uc_width
#define ulc_width_linebreaks libgettextpo_ulc_width_linebreaks
#define uniconv_register_autodetect libgettextpo_uniconv_register_autodetect
#define unilbrk_is_all_ascii libgettextpo_unilbrk_is_all_ascii
#define unilbrk_is_utf8_encoding libgettextpo_unilbrk_is_utf8_encoding
#define unilbrk_table libgettextpo_unilbrk_table
#define unilbrkprop libgettextpo_unilbrkprop
#define uninstall_sigfpe_handler libgettextpo_uninstall_sigfpe_handler
#define unregister_fd_hook libgettextpo_unregister_fd_hook
#define vasnprintf libgettextpo_vasnprintf
#define vasprintf libgettextpo_vasprintf
#define wcwidth libgettextpo_wcwidth
#define x2realloc libgettextpo_x2realloc
#define xalloc_die libgettextpo_xalloc_die
#define xasprintf libgettextpo_xasprintf
#define xcalloc libgettextpo_xcalloc
#define xconcatenated_filename libgettextpo_xconcatenated_filename
#define xmalloc libgettextpo_xmalloc
#define xmalloc_exit_failure libgettextpo_xmalloc_exit_failure
#define xmem_cd_iconv libgettextpo_xmem_cd_iconv
#define xmemdup libgettextpo_xmemdup
#define xmmalloca libgettextpo_xmmalloca
#define xnmalloc libgettextpo_xnmalloc
#define xrealloc libgettextpo_xrealloc
#define xstr_cd_iconv libgettextpo_xstr_cd_iconv
#define xstr_iconv libgettextpo_xstr_iconv
#define xstrdup libgettextpo_xstrdup
#define xvasprintf libgettextpo_xvasprintf
#define xzalloc libgettextpo_xzalloc
